package com.jdcloud.media.demo;

import android.Manifest;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.PixelFormat;
import android.net.Uri;
import android.os.Build;
import android.os.Handler;
import android.os.Message;
import android.provider.Settings;
import android.support.annotation.NonNull;
import android.support.v7.app.AlertDialog;
import android.view.Gravity;
import android.view.WindowManager;
import android.widget.TextView;
import android.widget.Toast;

import com.jd.sentry.annotation.StartupMainActivity;
import com.jdcloud.media.demo.base.BaseActivity;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.player.BasePlayerActivity;
import com.jdcloud.media.demo.player.GlobalPlayer;
import com.jdcloud.media.demo.player.widget.FloatWindow;
import com.jdcloud.media.demo.player.widget.JDPlayerView;
import com.jdcloud.media.demo.push.PushUtil;
import com.jdcloud.media.demo.push.ui.PushSettingActivity;
import com.jdcloud.media.demo.utils.ActivityUtil;
import com.jdcloud.media.demo.utils.LogUtil;
import com.jdcloud.media.demo.utils.PermissionUtils;
import com.jdcloud.media.demo.utils.ToastUtil;


import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

@StartupMainActivity
public class MainActivity extends BaseActivity implements Handler.Callback {

    @BindView(R.id.tv_app_ver)
    TextView mAppVerTv;

    private FloatWindow mFloatWidow;
    public static final int REMOVE_FLOATING_WINDOW = 0x10001;
    public static final int CLOSE_FLOATING_WINDOW = 0x10002;

    private Handler mHandler;
    private WindowManager.LayoutParams mFloatingViewParams;
    private WindowManager mWindowManager;

    private static final int PERMISSION_REQUEST_CODE = 1000;
    private static final int FLOAT_PERMISSION_CODE = 1001;
    private String[] permissions = {
            Manifest.permission.CAMERA,
            Manifest.permission.RECORD_AUDIO,
            Manifest.permission.READ_EXTERNAL_STORAGE,
            Manifest.permission.WRITE_EXTERNAL_STORAGE
    };

    private boolean formSetting = false;

    @Override
    public void initView() {
        setContentView(R.layout.activity_main);
        ButterKnife.bind(this);
        ActivityUtil.INSTANCE.addActivity(this);
    }

    @Override
    public void initData() {
        boolean checkResult = PermissionUtils.checkPermissionsGroup(this, permissions);
        if (!checkResult) {
            PermissionUtils.requestPermissions(this, permissions, PERMISSION_REQUEST_CODE);
        }

        mHandler = new android.os.Handler(getMainLooper(), this);
        mAppVerTv.setText(BuildConfig.VERSION_NAME);
    }

    private WindowManager getWindowManager(Context context) {
        if (mWindowManager == null) {
            mWindowManager = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
        }
        return mWindowManager;
    }

    private void initFloatWindow(Context context) {
        if (context == null)
            return;
        WindowManager windowManager = getWindowManager(context);
        int screenWidth = windowManager.getDefaultDisplay().getWidth();
        int screenHeight = windowManager.getDefaultDisplay().getHeight();
        if (mFloatWidow == null) {
            LogUtil.d("BLAY", "-------------------mFloatWidow == null");
            mFloatWidow = new FloatWindow(context);
            mFloatWidow.addFloatingWindow(GlobalPlayer.INSTANCE.getInstance());
            mFloatWidow.setHandler(mHandler);
            if (mFloatingViewParams == null) {
                mFloatingViewParams = new WindowManager.LayoutParams();
                mFloatingViewParams.type = Build.VERSION.SDK_INT >= 26 ? WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY : WindowManager.LayoutParams.TYPE_PHONE;
                mFloatingViewParams.flags = WindowManager.LayoutParams.FLAG_NOT_TOUCH_MODAL |
                        WindowManager.LayoutParams.FLAG_NOT_FOCUSABLE |
                        WindowManager.LayoutParams.FLAG_HARDWARE_ACCELERATED;
                mFloatingViewParams.format = PixelFormat.TRANSLUCENT;
                mFloatingViewParams.gravity = Gravity.LEFT | Gravity.TOP;
                mFloatingViewParams.width = getResources().getDimensionPixelSize(R.dimen.float_windows_width);
                mFloatingViewParams.height = getResources().getDimensionPixelSize(R.dimen.float_windows_height);
                mFloatingViewParams.x = screenWidth;
                mFloatingViewParams.y = screenHeight;
            }

            mFloatWidow.updateViewLayoutParams(mFloatingViewParams);
            windowManager.addView(mFloatWidow, mFloatingViewParams);
            LogUtil.d("BLAY", "------------float window added");
        } else {
            LogUtil.d("BLAY", "mFloatWidow != null");
        }
    }


    @Override
    public void initListener() {
    }

    @OnClick(R.id.ll_push_live)
    public void startPush() {
        startComponent(PushSettingActivity.class);
    }

    @OnClick(R.id.ll_video_player)
    public void startPlayer() {
        if (GlobalPlayer.INSTANCE.getInstance() != null) {
            if (mFloatWidow != null) {
                mHandler.sendEmptyMessage(REMOVE_FLOATING_WINDOW);
            } else {
                GlobalPlayer.INSTANCE.destroy();
                startComponent(BasePlayerActivity.class);
            }
        } else
            startComponent(BasePlayerActivity.class);

    }

    @Override
    protected void onResume() {
        super.onResume();
        if (GlobalPlayer.INSTANCE.getInstance() != null && JDPlayerView.PLAY_STATE==Constant.PLAYER.STARTED) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M && !Settings.canDrawOverlays(this)) {
                if (!formSetting) {
                    Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION,
                            Uri.parse("package:" + getPackageName()));
                    startActivityForResult(intent, FLOAT_PERMISSION_CODE);
                }
            } else {
                //悬浮窗播放
                LogUtil.d("BLAY","获取到悬浮窗权限");
                if (GlobalPlayer.INSTANCE.getInstance().getTag() != null) {
                    initFloatWindow(getApplicationContext());
                    GlobalPlayer.INSTANCE.getInstance().start();
                }
            }
        }
        formSetting = false;
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions,
                                           @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if (requestCode == PERMISSION_REQUEST_CODE) {
            boolean isAllGranted = true;
            for (int grant : grantResults) {
                if (grant != PackageManager.PERMISSION_GRANTED) {
                    isAllGranted = false;
                    break;
                }
            }
            if (!isAllGranted) {
                showPermissionDialog();
            }
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == FLOAT_PERMISSION_CODE && Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            if (Settings.canDrawOverlays(this)) {
//                LogUtil.d("BLAY","从设置中获取到悬浮窗权限");
                initFloatWindow(getApplicationContext());
                GlobalPlayer.INSTANCE.getInstance().start();
            } else {
                ToastUtil.makeText(this, "未能获取到权限，悬浮窗口播放失败！", Toast.LENGTH_SHORT);
                formSetting = true;
                if (mFloatWidow != null) {
                    mHandler.sendEmptyMessage(CLOSE_FLOATING_WINDOW);
                }
            }
        }
    }

    //系统授权设置的弹框
    AlertDialog openAppDetDialog = null;

    private void showPermissionDialog() {
        AlertDialog.Builder builder = new AlertDialog.Builder(this);
        builder.setMessage(getString(R.string.app_name) + "需要访问 \"相册\"、\"摄像头\" 和 \"外部存储器\",否则会影响绝大部分功能使用, 请到 \"应用信息 -> 权限\" 中设置！");
        builder.setPositiveButton("去设置", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                Intent intent = new Intent();
                intent.setAction(Settings.ACTION_APPLICATION_DETAILS_SETTINGS);
                intent.addCategory(Intent.CATEGORY_DEFAULT);
                intent.setData(Uri.parse("package:" + getPackageName()));
                intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
                intent.addFlags(Intent.FLAG_ACTIVITY_NO_HISTORY);
                intent.addFlags(Intent.FLAG_ACTIVITY_EXCLUDE_FROM_RECENTS);
                startActivity(intent);
            }
        });
        builder.setCancelable(false);
        builder.setNegativeButton("暂不设置", new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                finish();
            }
        });
        if (null == openAppDetDialog) {
            openAppDetDialog = builder.create();
        }
        if (null != openAppDetDialog && !openAppDetDialog.isShowing()) {
            openAppDetDialog.show();
        }
    }

    @Override
    public boolean handleMessage(Message msg) {

        switch (msg.what) {
            case REMOVE_FLOATING_WINDOW:
                //click floating player
                removeFloatWindowGoPlayer();
                break;
            case CLOSE_FLOATING_WINDOW:
                closeFloat();
                break;
            default:
                break;
        }
        return false;
    }

    private void removeFloatWindowGoPlayer() {
        mFloatWidow.removeFloatingWindow(GlobalPlayer.INSTANCE.getInstance());
        mWindowManager.removeView(mFloatWidow);
        mFloatWidow = null;
        startComponent(BasePlayerActivity.class);
    }

    private void closeFloat() {
        mFloatWidow.removeFloatingWindow(GlobalPlayer.INSTANCE.getInstance());
        if (GlobalPlayer.INSTANCE.getInstance() != null) {
            GlobalPlayer.INSTANCE.destroy();
        }
        mWindowManager.removeView(mFloatWidow);
        mFloatWidow = null;
    }

    @Override
    public void onBackPressed() {
        super.onBackPressed();
        if (mFloatWidow != null) {
            mHandler.sendEmptyMessage(CLOSE_FLOATING_WINDOW);
        }
        if (PushUtil.INSTANCE.isFloatViewShow()) {
            PushUtil.INSTANCE.destroyStreamer();
        }
        ActivityUtil.INSTANCE.exit();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
    }
}
