package com.jdcloud.media.demo.common;

import android.content.Intent;
import android.graphics.Bitmap;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;
import android.view.View;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.google.zxing.Result;
import com.google.zxing.client.result.ParsedResult;
import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.base.BaseActivity;
import com.jdcloud.media.demo.utils.ToastUtil;
import com.mylhyl.zxing.scanner.OnScannerCompletionListener;
import com.mylhyl.zxing.scanner.ScannerView;
import com.mylhyl.zxing.scanner.common.Scanner;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class QRCodeScannerActivity extends BaseActivity implements OnScannerCompletionListener {
    @BindView(R.id.action_bar_back)
    RelativeLayout mActionBarBack;
    @BindView(R.id.action_bar_setting)
    RelativeLayout mActionBarSetting;
    @BindView(R.id.action_bar_title)
    TextView mTitle;
    @BindView(R.id.scanner_view)
    ScannerView mScannerView;

    private Handler mHandler;
    private static final int MSG_SHOW_TOAST = 0x1001;
    private static final int MSG_RESUME_CAMERA = 0x1002;
    private BaseActivity mContext;
    public static final String SCAN_RESULT = "scan_result";

    @Override
    public void initView() {
        setContentView(R.layout.activity_scanner);
        ButterKnife.bind(this);
        mContext = this;
    }

    @Override
    public void initData() {
        mHandler = new UIHandler();
        mScannerView.setScanMode(Scanner.ScanMode.QR_CODE_MODE);
        mScannerView.setLaserFrameBoundColor(getResources().getColor(R.color.common_btn_selected_color));
        mScannerView.setLaserColor(getResources().getColor(R.color.btn_selected_color));
    }

    @Override
    public void onResume() {
        mScannerView.onResume();
        super.onResume();
    }

    @Override
    public void setActionBar() {
        super.setActionBar();
        mTitle.setText(R.string.title_scan);
        mActionBarBack.setVisibility(View.VISIBLE);
        mActionBarSetting.setVisibility(View.GONE);
    }

    @Override
    public void onPause() {
        mScannerView.onPause();
        super.onPause();
    }

    //返回
    @OnClick(R.id.action_bar_back)
    public void goBack() {
        onBackPressed();
    }

    @Override
    public void initListener() {
        mScannerView.setOnScannerCompletionListener(this);
    }

    @Override
    public void onScannerCompletion(Result rawResult, ParsedResult parsedResult, Bitmap barcode) {

        if (rawResult != null) {
            String url = rawResult.toString();
            Intent intent = new Intent();
            if (!TextUtils.isEmpty(url)) {
                intent.putExtra(SCAN_RESULT, url);
            } else {
                mHandler.sendEmptyMessage(MSG_SHOW_TOAST);
            }
            setResult(RESULT_OK, intent);
            mHandler.sendEmptyMessageDelayed(MSG_RESUME_CAMERA, 2000);
            finish();
        }

    }

    class UIHandler extends Handler {
        @Override
        public void handleMessage(Message msg) {

            switch (msg.what) {
                case MSG_SHOW_TOAST:
                    ToastUtil.makeText(mContext, Constant.SCAN_EMPTY_URL_ERROR, Toast.LENGTH_SHORT);
                    break;
                case MSG_RESUME_CAMERA:
                    break;
                default:
                    break;
            }
        }
    }

}
