package com.jdcloud.media.demo.common.view;

import android.app.Dialog;
import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.TextView;

import com.jdcloud.media.demo.R;

public class CustomDialog extends Dialog {

    public CustomDialog(Context context) {
        super(context);
    }

    public CustomDialog(Context context, int theme) {
        super(context, theme);
    }

    public static class Builder {
        private View.OnClickListener positiveButtonClickListener;
        private View.OnClickListener negativeButtonClickListener;

        private View layout;
        private TextView mTitle;
        private TextView mContent;
        private CustomDialog dialog;
        private TextView mOkBtn;
        private TextView mCancelBtn;

        public Builder(Context context) {
            dialog = new CustomDialog(context, R.style.custom_dialog);
            LayoutInflater inflater = (LayoutInflater) context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
            layout = inflater.inflate(R.layout.layout_common_dialog, null);
            mTitle = layout.findViewById(R.id.tv_dialog_title);
            mContent = layout.findViewById(R.id.tv_dialog_content);
            mOkBtn = layout.findViewById(R.id.tv_dialog_ok);
            mCancelBtn = layout.findViewById(R.id.tv_dialog_cancel);
            dialog.setContentView(layout);
        }

        public Builder setOkListener(View.OnClickListener listener) {
            positiveButtonClickListener = listener;
            return this;
        }

        public Builder setCancelListener(View.OnClickListener listener) {
            negativeButtonClickListener = listener;
            return this;
        }

        public Builder setTitle(int title) {
            mTitle.setText(title);
            return this;
        }

        public Builder setContent(int content) {
            mContent.setText(content);
            return this;
        }

        public Builder setOkBtn(int ok) {
            mOkBtn.setText(ok);
            return this;
        }

        public Builder setCancelBtn(int cancel) {
            mCancelBtn.setText(cancel);
            return this;
        }

        public CustomDialog createDialog() {
            mOkBtn.setOnClickListener(positiveButtonClickListener);
            mCancelBtn.setOnClickListener(negativeButtonClickListener);
            create();
            return dialog;
        }

        private void create() {
            dialog.setContentView(layout);
            dialog.setCancelable(true);
            dialog.setCanceledOnTouchOutside(false);
        }
    }
}
