package com.jdcloud.media.demo.common.view;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.content.res.TypedArray;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.Path;
import android.graphics.Point;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.text.InputFilter;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.DisplayMetrics;
import android.util.TypedValue;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.widget.EditText;
import android.widget.Toast;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.utils.CommonUtils;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public class WaterMarkEditView extends View {

    private Context mContext;
    /**
     * 图片的最大缩放比例
     */
    private static final float MAX_SCALE = 4.0f;

    /**
     * 图片的最小缩放比例
     */
    private static final float MIN_SCALE = 0.3f;

    /**
     * 控制缩放，旋转图标所在四个点得位置
     */
    private static final int LEFT_TOP = 0;
    private static final int RIGHT_TOP = 1;
    private static final int RIGHT_BOTTOM = 2;
    private static final int LEFT_BOTTOM = 3;

    /**
     * 一些默认的常量
     */
    private static final int DEFAULT_FRAME_PADDING = 0;
    private static final int DEFAULT_FRAME_WIDTH = 2;
    private static final int DEFAULT_FRAME_COLOR = Color.WHITE;
    private static final float DEFAULT_SCALE = 1.0f;
    private static final float DEFAULT_DEGREE = 0;
    private static final int DEFAULT_CONTROL_LOCATION = RIGHT_TOP;
    private static final boolean DEFAULT_EDITABLE = true;
    private static final int DEFAULT_OTHER_DRAWABLE_WIDTH = 120;
    private static final int DEFAULT_OTHER_DRAWABLE_HEIGHT = 120;


    private boolean isMeasured;

    /**
     * 用于旋转缩放的Bitmap
     */
    private Bitmap mBitmap;

    private PointF mCenterPoint = new PointF();

    /**
     * View的宽度和高度，随着图片的旋转而变化(不包括控制旋转，缩放图片的宽高)
     */
    private int mViewWidth, mViewHeight;

    /**
     * 图片的旋转角度
     */
    private float mDegree = DEFAULT_DEGREE;

    /**
     * 图片的缩放比例
     */
    private float mScale = DEFAULT_SCALE;

    private Matrix matrix = new Matrix();

    private int mViewPaddingLeft;
    private int mViewPaddingTop;

    /**
     * 图片四个点坐标
     */
    private Point mLTPoint;
    private Point mRTPoint;
    private Point mRBPoint;
    private Point mLBPoint;
    /**
     * 用于编辑的控制点的坐标
     */
    private Point mEditPoint = new Point();

    private Drawable mEditDrawable;

    private int mEditDrawableWidth, mEditDrawableHeight;
    private AlertDialog mTextEditDialog;
    private EditText mEditText;
    private final String DEFAULT_TEXT = "京东视频云";
    /**
     * 用于删除的控制点的坐标
     */
    private Point mDeletePoint = new Point();

    private Drawable mDeleteDrawable;

    private int mDeleteDrawableWidth, mDeleteDrawableHeight;

    /**
     * 用于缩放，旋转的控制点的坐标
     */
    private Point mControlPoint = new Point();

    /**
     * 用于缩放，旋转的图标
     */
    private Drawable mControlDrawable;

    /**
     * 缩放，旋转图标的宽和高
     */
    private int mControlDrawableWidth, mControlDrawableHeight;

    /**
     * 画外围框的Path
     */
    private Path mPath = new Path();

    /**
     * 画外围框的画笔
     */
    private Paint mPaint;

    /**
     * 初始状态
     */
    private static final int STATUS_INIT = 0;

    /**
     * 拖动状态
     */
    private static final int STATUS_DRAG = 1;

    /**
     * 旋转或者放大状态
     */
    private static final int STATUS_ROTATE_ZOOM = 2;
    /**
     * 点击编辑状态
     */
    private static final int STATUS_EDIT = 3;
    /**
     * 点击删除状态
     */
    private static final int STATUS_DELETE = 4;

    /**
     * 当前所处的状态
     */
    private int mStatus = STATUS_INIT;

    /**
     * 外边框与图片之间的间距, 单位是dip
     */
    private int mFramePadding = DEFAULT_FRAME_PADDING;

    /**
     * 外边框颜色
     */
    private int frameColor = DEFAULT_FRAME_COLOR;

    /**
     * 外边框线条粗细, 单位是 dip
     */
    private int frameWidth = DEFAULT_FRAME_WIDTH;

    /**
     * 是否处于可以缩放，平移，旋转状态
     */
    private boolean isEditable = DEFAULT_EDITABLE;

    private DisplayMetrics metrics;


    private PointF mPreMovePointF = new PointF();
    private PointF mCurMovePointF = new PointF();

    /**
     * 图片在旋转时x方向的偏移量
     */
    private int offsetX;
    /**
     * 图片在旋转时y方向的偏移量
     */
    private int offsetY;

    /**
     * 控制图标所在的位置（比如左上，右上，左下，右下）
     */
    private int mControlLocation = RIGHT_BOTTOM;

    private int mEditLocation = RIGHT_TOP;

    private int mDeleteLocation = LEFT_TOP;
    private int mX;
    private int mY;
    private int width;
    private int height;
    private String mText;//水印文字
    private boolean isText;//是否为文字水印
    private int mTextColor = Color.WHITE;//文字颜色
    private boolean isTime;
    private boolean isPhotoSet;

    public WaterMarkEditView(Context context, AttributeSet attrs) {
        this(context, attrs, 0);
    }

    public WaterMarkEditView(Context context) {
        this(context, null);
    }

    public WaterMarkEditView(Context context, AttributeSet attrs, int defStyle) {
        super(context, attrs, defStyle);
        obtainStyledAttributes(attrs);
        this.mContext = context;
        init();
    }

    public void setPhoto(boolean photoSeted) {
        this.isPhotoSet = photoSeted;
    }

    public void setTextWater(boolean isTextWater) {
        this.isText = isTextWater;
    }

    private void obtainStyledAttributes(AttributeSet attrs) {
        metrics = getContext().getResources().getDisplayMetrics();
        mFramePadding = (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, DEFAULT_FRAME_PADDING, metrics);
        frameWidth = (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, DEFAULT_FRAME_WIDTH, metrics);

        TypedArray mTypedArray = getContext().obtainStyledAttributes(attrs, R.styleable.water_mark_edit);

        Drawable srcDrawable = mTypedArray.getDrawable(R.styleable.water_mark_edit_src);
        mBitmap = drawable2Bitmap(srcDrawable);

        mFramePadding = mTypedArray.getDimensionPixelSize(R.styleable.water_mark_edit_framePadding, mFramePadding);
        frameWidth = mTypedArray.getDimensionPixelSize(R.styleable.water_mark_edit_frameWidth, frameWidth);
        frameColor = mTypedArray.getColor(R.styleable.water_mark_edit_frameColor, DEFAULT_FRAME_COLOR);
        mScale = mTypedArray.getFloat(R.styleable.water_mark_edit_scale, DEFAULT_SCALE);
        mDegree = mTypedArray.getFloat(R.styleable.water_mark_edit_degree, DEFAULT_DEGREE);
        mControlDrawable = mTypedArray.getDrawable(R.styleable.water_mark_edit_controlDrawable);
        mControlLocation = mTypedArray.getInt(R.styleable.water_mark_edit_controlLocation, RIGHT_BOTTOM);

        mEditDrawable = mTypedArray.getDrawable(R.styleable.water_mark_edit_editDrawable);
        mEditLocation = mTypedArray.getInt(R.styleable.water_mark_edit_editLocation, RIGHT_TOP);

        mDeleteDrawable = mTypedArray.getDrawable(R.styleable.water_mark_edit_deleteDrawable);
        mDeleteLocation = mTypedArray.getInt(R.styleable.water_mark_edit_deleteLocation, LEFT_TOP);

        isEditable = mTypedArray.getBoolean(R.styleable.water_mark_edit_editable, DEFAULT_EDITABLE);

        mTypedArray.recycle();
    }


    private void init() {
        mPaint = new Paint();
        mPaint.setAntiAlias(true);
        mPaint.setColor(frameColor);
        mPaint.setStrokeWidth(frameWidth);
        mPaint.setStyle(Paint.Style.STROKE);

        if (mControlDrawable != null) {
            mControlDrawableWidth = (int) (mControlDrawable.getIntrinsicWidth() * 1.5);
            mControlDrawableHeight = (int) (mControlDrawable.getIntrinsicHeight() * 1.5);
        }
        if (mEditDrawable != null) {
            mEditDrawableWidth = (int) (mEditDrawable.getIntrinsicWidth() * 1.5);
            mEditDrawableHeight = (int) (mEditDrawable.getIntrinsicHeight() * 1.5);
        }
        if (mDeleteDrawable != null) {
            mDeleteDrawableWidth = (int) (mDeleteDrawable.getIntrinsicWidth() * 1.5);
            mDeleteDrawableHeight = (int) (mDeleteDrawable.getIntrinsicHeight() * 1.5);
        }

        transformDraw();
    }

    @Override
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
        super.onMeasure(widthMeasureSpec, heightMeasureSpec);
        if (!isMeasured) {
            ViewGroup mViewGroup = (ViewGroup) getParent();
            if (null != mViewGroup) {
                int parentWidth = mViewGroup.getWidth();
                int parentHeight = mViewGroup.getHeight();
                mCenterPoint.set(parentWidth / 2, parentHeight / 2);
            }
            isMeasured = true;
            adjustLayout();
        }
    }

    @Override
    protected void onSizeChanged(int w, int h, int oldw, int oldh) {
        super.onSizeChanged(w, h, oldw, oldh);
    }

    private void adjustLayout() {
        if (mCenterPoint.x <= 0 || mCenterPoint.y <= 0) {
            mCenterPoint.set(mCenterX, mCenterY);
        }
        int actualWidth = mViewWidth + mControlDrawableWidth;
        int actualHeight = mViewHeight + mControlDrawableHeight;
        int newPaddingLeft = (int) (mCenterPoint.x - actualWidth / 2);
        int newPaddingTop = (int) (mCenterPoint.y - actualHeight / 2);

        if (mViewPaddingLeft != newPaddingLeft || mViewPaddingTop != newPaddingTop) {
            mViewPaddingLeft = newPaddingLeft;
            mViewPaddingTop = newPaddingTop;
        }
        layout(newPaddingLeft, newPaddingTop, newPaddingLeft + actualWidth, newPaddingTop + actualHeight);
        this.mX = newPaddingLeft + mControlDrawableWidth / 2;
        this.mY = newPaddingTop + mControlDrawableHeight / 2;
        this.width = mViewWidth;
        this.height = mViewHeight;
    }

    private IClickListener mClickListener = null;

    public void setClickListener(IClickListener listener) {
        mClickListener = listener;
    }

    public interface IClickListener {
        void onDeleteClick();

        void onSaveClick();

        void onEditClick();
    }

    public void setImageBitmap(Bitmap bitmap) {
        if (this.mBitmap != null && bitmap != null && !this.mBitmap.equals(bitmap)) {
            this.mBitmap.recycle();
        }
        Bitmap BitmapOrg = bitmap;
        int width = BitmapOrg.getWidth();
        int height = BitmapOrg.getHeight();
        int newWidth = mContext.getResources().getDimensionPixelSize(R.dimen.water_mark_photo_width);
        int newHeight = mContext.getResources().getDimensionPixelSize(R.dimen.water_mark_photo_height);
        float scaleWidth = ((float) newWidth) / width;
        float scaleHeight = ((float) newHeight) / height;
        Matrix matrix = new Matrix();
        matrix.postScale(scaleWidth, scaleHeight);
        Bitmap resizedBitmap = Bitmap.createBitmap(BitmapOrg, 0, 0, width, height, matrix, true);

        this.mBitmap = resizedBitmap;
        mScale = 1.0f;
        mDegree = 0;
        mFramePadding = 0;
        transformDraw();
    }

    public Bitmap getImageBitmap() {
        return this.mBitmap;
    }

    public String getWaterText() {
        return TextUtils.isEmpty(mText) ? DEFAULT_TEXT : mText;
    }

    public int getImageX() {
        return this.mX;
    }


    public int getImageY() {
        return this.mY;
    }

    public int getImageWidth() {
        return this.width;
    }

    public int getImageHeight() {
        return this.height;
    }

    public void showTime() {
        setIsTime(true);
        setTextWater(false);
        invalidate();
        transformDraw();
        setVisibility(VISIBLE);
        isPhotoSet = true;
    }

    public void showText() {
        setTextWater(true);
        setIsTime(false);
        invalidate();
        transformDraw();
        setVisibility(VISIBLE);
    }

    public void showPhoto() {
        setIsTime(false);
        setTextWater(false);
        invalidate();
        transformDraw();
        setVisibility(VISIBLE);
    }

    public void setIsTime(boolean isTimed) {
        isTime = isTimed;
    }

    private Bitmap drawable2Bitmap(Drawable drawable) {
        try {
            if (drawable == null) {
                return null;
            }

            if (drawable instanceof BitmapDrawable) {
                return ((BitmapDrawable) drawable).getBitmap();
            }

            int intrinsicWidth = drawable.getIntrinsicWidth();
            int intrinsicHeight = drawable.getIntrinsicHeight();
            Bitmap bitmap = Bitmap.createBitmap(
                    intrinsicWidth <= 0 ? DEFAULT_OTHER_DRAWABLE_WIDTH
                            : intrinsicWidth,
                    intrinsicHeight <= 0 ? DEFAULT_OTHER_DRAWABLE_HEIGHT
                            : intrinsicHeight, Bitmap.Config.ARGB_8888);

            Canvas canvas = new Canvas(bitmap);
            drawable.setBounds(0, 0, canvas.getWidth(), canvas.getHeight());
            drawable.draw(canvas);
            return bitmap;
        } catch (OutOfMemoryError e) {
            return null;
        }

    }

    @Override
    protected void onDraw(Canvas canvas) {
        //每次draw之前调整View的位置和大小
        super.onDraw(canvas);
        if (mBitmap != null) {
            canvas.drawBitmap(mBitmap, matrix, mPaint);
        }
        if (isTime || isText) {
            drawTime(canvas);
        }
        //处于可编辑状态才画边框和控制图标
        if (isEditable) {
            mPath.reset();
            mPath.moveTo(mLTPoint.x, mLTPoint.y);
            mPath.lineTo(mRTPoint.x, mRTPoint.y);
            mPath.lineTo(mRBPoint.x, mRBPoint.y);
            mPath.lineTo(mLBPoint.x, mLBPoint.y);
            mPath.lineTo(mLTPoint.x, mLTPoint.y);
            mPath.lineTo(mRTPoint.x, mRTPoint.y);
            canvas.drawPath(mPath, mPaint);
            //画旋转, 缩放图标

            if (mControlDrawable != null) {
                mControlDrawable.setBounds(mControlPoint.x - mControlDrawableWidth / 2,
                        mControlPoint.y - mControlDrawableHeight / 2, mControlPoint.x + mControlDrawableWidth
                                / 2, mControlPoint.y + mControlDrawableHeight / 2);
                mControlDrawable.draw(canvas);
            }

            if (mEditDrawable != null) {
                mEditDrawable.setBounds(mEditPoint.x - mControlDrawableWidth / 2,
                        mEditPoint.y - mControlDrawableHeight / 2, mEditPoint.x + mControlDrawableWidth
                                / 2, mEditPoint.y + mControlDrawableHeight / 2);
                mEditDrawable.draw(canvas);
            }

            if (mDeleteDrawable != null) {
                mDeleteDrawable.setBounds(mDeletePoint.x - mControlDrawableWidth / 2,
                        mDeletePoint.y - mControlDrawableHeight / 2, mDeletePoint.x + mControlDrawableWidth
                                / 2, mDeletePoint.y + mControlDrawableHeight / 2);
                mDeleteDrawable.draw(canvas);
            }
        }
        adjustLayout();
    }

    private void drawTime(Canvas canvas) {
        if (mBitmap == null || mTextPaint == null || mBounds == null) {
            return;
        }
        if (isText) {
            drawTextToBitmap(canvas, mBitmap, !TextUtils.isEmpty(mText) ? mText : DEFAULT_TEXT, mTextPaint, mBounds, (mViewWidth - mBounds.width()) / 2, (mViewHeight + mBounds.height()) / 2);
        } else {
            drawTextToBitmap(canvas, mBitmap, CommonUtils.timeFormat(), mTextPaint, mBounds, (mViewWidth - mBounds.width()) / 2, (mViewHeight + mBounds.height()) / 2);
        }

    }

    public void updateTextColor(int color) {
        if (mTextPaint == null) {
            return;
        }
        mTextColor = color;
        if (isText) {
            showText();
        } else if (isTime) {
            showTime();
        }
    }

    private Bitmap drawTextToBitmap(Canvas canvas, Bitmap bitmap, String text, Paint paint,
                                    Rect bounds, int paddingLeft, int paddingTop) {
        Bitmap.Config bitmapConfig = bitmap.getConfig();

        paint.setDither(true); // 获取跟清晰的图像采样
        paint.setFilterBitmap(true);// 过滤一些
        if (bitmapConfig == null) {
            bitmapConfig = Bitmap.Config.ARGB_8888;
        }
        bitmap = bitmap.copy(bitmapConfig, true);
        if (canvas == null) {
            canvas = new Canvas(bitmap);
        }
        canvas.drawText(text, paddingLeft, paddingTop, paint);
        return bitmap;
    }

    private Paint mTextPaint;
    private Rect mBounds;

    private void transformDraw() {
        if (mTextPaint == null) {
            mTextPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
            mTextPaint.setAntiAlias(true);
            mBounds = new Rect();
            float textPixelSize = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_SP,
                    10, getResources().getDisplayMetrics());
            mTextPaint.setTextSize(textPixelSize);
        }
        if (isText) {
            mTextPaint.getTextBounds(TextUtils.isEmpty(mText) ? DEFAULT_TEXT : mText, 0, TextUtils.isEmpty(mText) ? DEFAULT_TEXT.length() : mText.length(), mBounds);
            mTextPaint.setColor(mTextColor);
        } else if (isTime) {
            mTextPaint.getTextBounds(CommonUtils.timeFormat(), 0, CommonUtils.timeFormat().length(), mBounds);
            mTextPaint.setColor(mTextColor);
        } else {
            if (mBitmap == null) return;
            int bitmapWidth = (int) (mBitmap.getWidth() * mScale);
            int bitmapHeight = (int) (mBitmap.getHeight() * mScale);
            computeRect(-mFramePadding, -mFramePadding, bitmapWidth + mFramePadding, bitmapHeight + mFramePadding, mDegree);

            //设置缩放比例
            matrix.setScale(mScale, mScale);
            //绕着图片中心进行旋转
            matrix.postRotate(mDegree % 360, bitmapWidth / 2, bitmapHeight / 2);
            //设置画该图片的起始点
            matrix.postTranslate(offsetX + mControlDrawableWidth / 2, offsetY + mControlDrawableHeight / 2);
        }
        adjustLayout();
    }

    private float mDownX, mDownY;

    public boolean onTouchEvent(MotionEvent event) {
        if (!isEditable) {
            return super.onTouchEvent(event);
        }
        switch (event.getAction()) {
            case MotionEvent.ACTION_DOWN:
                mPreMovePointF.set(event.getX() + mViewPaddingLeft, event.getY() + mViewPaddingTop);

                mStatus = judgeStatus(event.getX(), event.getY());
                if (mStatus == STATUS_DRAG) {
                    mDownX = event.getX();
                    mDownY = event.getY();
                }
                break;
            case MotionEvent.ACTION_UP:
                if (mClickListener != null) {
                    //再次判定抬起点 是否处于icon的范围之内
                    int secondJudgeState = judgeStatus(event.getX(), event.getY());
                    //满足才触发回调
                    if (mStatus == STATUS_EDIT && secondJudgeState == mStatus) {
                        if (isPhotoSet) {
                            mClickListener.onSaveClick();
                        } else {
                            Toast.makeText(mContext, "请先设置水印图片！", Toast.LENGTH_SHORT).show();
                        }
                    }
                    if (mStatus == STATUS_DELETE && secondJudgeState == mStatus) {
                        mClickListener.onDeleteClick();
                    }
                    if (mStatus == STATUS_ROTATE_ZOOM || mStatus == STATUS_DRAG) {
                        mClickListener.onEditClick();
                    }
                }
                if (mDownX == event.getX() && mDownY == event.getY()) {
                    if (isText) {
                        if (mTextEditDialog == null) {
                            mEditText = new EditText(mContext);
                            mEditText.setText(DEFAULT_TEXT);
                            mEditText.setFilters(new InputFilter[]{new InputFilter.LengthFilter(10)});
                            mTextEditDialog = new AlertDialog.Builder(mContext).setTitle("请输入文字")
                                    .setView(mEditText)
                                    .setPositiveButton("确定", new DialogInterface.OnClickListener() {
                                        @Override
                                        public void onClick(DialogInterface dialogInterface, int i) {
                                            mText = mEditText.getText().toString();
                                            mTextEditDialog.dismiss();
                                            isPhotoSet = true;
                                            showText();
                                        }
                                    }).setNegativeButton("取消", new DialogInterface.OnClickListener() {
                                        @Override
                                        public void onClick(DialogInterface dialogInterface, int i) {
                                            isPhotoSet = true;
                                            mTextEditDialog.cancel();
                                        }
                                    }).create();
                        }
                        mTextEditDialog.show();
                    }
                }
                mStatus = STATUS_INIT;
                break;
            case MotionEvent.ACTION_MOVE:
                mCurMovePointF.set(event.getX() + mViewPaddingLeft, event.getY() + mViewPaddingTop);
                if (mStatus == STATUS_ROTATE_ZOOM) {
                    float scale = 1f;

                    int halfBitmapWidth = mBitmap.getWidth() / 2;
                    int halfBitmapHeight = mBitmap.getHeight() / 2;

                    //图片某个点到图片中心的距离
                    float bitmapToCenterDistance = (float) Math.sqrt(halfBitmapWidth * halfBitmapWidth + halfBitmapHeight * halfBitmapHeight);

                    //移动的点到图片中心的距离
                    float moveToCenterDistance = distance4PointF(mCenterPoint, mCurMovePointF);

                    //计算缩放比例
                    scale = moveToCenterDistance / bitmapToCenterDistance;


                    //缩放比例的界限判断
                    if (scale <= MIN_SCALE) {
                        scale = MIN_SCALE;
                    } else if (scale >= MAX_SCALE) {
                        scale = MAX_SCALE;
                    }


                    // 角度
                    double a = distance4PointF(mCenterPoint, mPreMovePointF);
                    double b = distance4PointF(mPreMovePointF, mCurMovePointF);
                    double c = distance4PointF(mCenterPoint, mCurMovePointF);

                    double cosb = (a * a + c * c - b * b) / (2 * a * c);

                    if (cosb >= 1) {
                        cosb = 1f;
                    }

                    double radian = Math.acos(cosb);
                    float newDegree = (float) radianToDegree(radian);

                    //center -> proMove的向量， 我们使用PointF来实现
                    PointF centerToProMove = new PointF((mPreMovePointF.x - mCenterPoint.x), (mPreMovePointF.y - mCenterPoint.y));

                    //center -> curMove 的向量
                    PointF centerToCurMove = new PointF((mCurMovePointF.x - mCenterPoint.x), (mCurMovePointF.y - mCenterPoint.y));

                    //向量叉乘结果, 如果结果为负数， 表示为逆时针， 结果为正数表示顺时针
                    float result = centerToProMove.x * centerToCurMove.y - centerToProMove.y * centerToCurMove.x;

                    if (result < 0) {
                        newDegree = -newDegree;
                    }

                    mDegree = mDegree + newDegree;
                    mScale = scale;

                    transformDraw();
                } else if (mStatus == STATUS_DRAG) {
                    // 修改中心点
                    mCenterPoint.x += mCurMovePointF.x - mPreMovePointF.x;
                    mCenterPoint.y += mCurMovePointF.y - mPreMovePointF.y;
                    System.out.println(this + "move = " + mCenterPoint);

                    adjustLayout();
                }

                mPreMovePointF.set(mCurMovePointF);
                break;
        }
        return true;
    }


    private void computeRect(int left, int top, int right, int bottom, float degree) {
        Point lt = new Point(left, top);
        Point rt = new Point(right, top);
        Point rb = new Point(right, bottom);
        Point lb = new Point(left, bottom);
        Point cp = new Point((left + right) / 2, (top + bottom) / 2);
        mLTPoint = obtainRotationPoint(cp, lt, degree);
        mRTPoint = obtainRotationPoint(cp, rt, degree);
        mRBPoint = obtainRotationPoint(cp, rb, degree);
        mLBPoint = obtainRotationPoint(cp, lb, degree);

        //计算X坐标最大的值和最小的值
        int maxCoordinateX = getMaxValue(mLTPoint.x, mRTPoint.x, mRBPoint.x, mLBPoint.x);
        int minCoordinateX = getMinValue(mLTPoint.x, mRTPoint.x, mRBPoint.x, mLBPoint.x);

        mViewWidth = maxCoordinateX - minCoordinateX;
        //标记左上角和右下角的X Y坐标
        mX = mLTPoint.x;
        mY = mLBPoint.y;
        //计算Y坐标最大的值和最小的值
        int maxCoordinateY = getMaxValue(mLTPoint.y, mRTPoint.y, mRBPoint.y, mLBPoint.y);
        int minCoordinateY = getMinValue(mLTPoint.y, mRTPoint.y, mRBPoint.y, mLBPoint.y);

        mViewHeight = maxCoordinateY - minCoordinateY;


        //View中心点的坐标
        Point viewCenterPoint = new Point((maxCoordinateX + minCoordinateX) / 2, (maxCoordinateY + minCoordinateY) / 2);

        offsetX = mViewWidth / 2 - viewCenterPoint.x;
        offsetY = mViewHeight / 2 - viewCenterPoint.y;


        int halfDrawableWidth = mControlDrawableWidth / 2;
        int halfDrawableHeight = mControlDrawableHeight / 2;

        //将Bitmap的四个点的X的坐标移动offsetX + halfDrawableWidth
        mLTPoint.x += (offsetX + halfDrawableWidth);
        mRTPoint.x += (offsetX + halfDrawableWidth);
        mRBPoint.x += (offsetX + halfDrawableWidth);
        mLBPoint.x += (offsetX + halfDrawableWidth);

        //将Bitmap的四个点的Y坐标移动offsetY + halfDrawableHeight
        mLTPoint.y += (offsetY + halfDrawableHeight);
        mRTPoint.y += (offsetY + halfDrawableHeight);
        mRBPoint.y += (offsetY + halfDrawableHeight);
        mLBPoint.y += (offsetY + halfDrawableHeight);

        mControlPoint = locatePoint(mControlLocation);
        mEditPoint = locatePoint(mEditLocation);
        mDeletePoint = locatePoint(mDeleteLocation);
    }

    private Point locatePoint(int location) {
        switch (location) {
            case LEFT_TOP:
                return mLTPoint;
            case RIGHT_TOP:
                return mRTPoint;
            case RIGHT_BOTTOM:
                return mRBPoint;
            case LEFT_BOTTOM:
                return mLBPoint;
        }
        return mLTPoint;
    }

    public int getMaxValue(Integer... array) {
        List<Integer> list = Arrays.asList(array);
        Collections.sort(list);
        return list.get(list.size() - 1);
    }

    public int getMinValue(Integer... array) {
        List<Integer> list = Arrays.asList(array);
        Collections.sort(list);
        return list.get(0);
    }

    private Point obtainRotationPoint(Point center, Point source, float degree) {
        //两者之间的距离
        Point disPoint = new Point();
        disPoint.x = source.x - center.x;
        disPoint.y = source.y - center.y;

        //没旋转之前的弧度
        double originRadian = 0;

        //没旋转之前的角度
        double originDegree = 0;

        //旋转之后的角度
        double resultDegree = 0;

        //旋转之后的弧度
        double resultRadian = 0;

        //经过旋转之后点的坐标
        Point resultPoint = new Point();

        double distance = Math.sqrt(disPoint.x * disPoint.x + disPoint.y * disPoint.y);
        if (disPoint.x == 0 && disPoint.y == 0) {
            return center;
            // 第一象限
        } else if (disPoint.x >= 0 && disPoint.y >= 0) {
            // 计算与x正方向的夹角
            originRadian = Math.asin(disPoint.y / distance);

            // 第二象限
        } else if (disPoint.x < 0 && disPoint.y >= 0) {
            // 计算与x正方向的夹角
            originRadian = Math.asin(Math.abs(disPoint.x) / distance);
            originRadian = originRadian + Math.PI / 2;

            // 第三象限
        } else if (disPoint.x < 0 && disPoint.y < 0) {
            // 计算与x正方向的夹角
            originRadian = Math.asin(Math.abs(disPoint.y) / distance);
            originRadian = originRadian + Math.PI;
        } else if (disPoint.x >= 0 && disPoint.y < 0) {
            // 计算与x正方向的夹角
            originRadian = Math.asin(disPoint.x / distance);
            originRadian = originRadian + Math.PI * 3 / 2;
        }

        // 弧度换算成角度
        originDegree = radianToDegree(originRadian);
        resultDegree = originDegree + degree;

        // 角度转弧度
        resultRadian = degreeToRadian(resultDegree);

        resultPoint.x = (int) Math.round(distance * Math.cos(resultRadian));
        resultPoint.y = (int) Math.round(distance * Math.sin(resultRadian));
        resultPoint.x += center.x;
        resultPoint.y += center.y;

        return resultPoint;
    }

    private double radianToDegree(double radian) {
        return radian * 180 / Math.PI;
    }

    private double degreeToRadian(double degree) {
        return degree * Math.PI / 180;
    }

    private int judgeStatus(float x, float y) {
        PointF touchPoint = new PointF(x, y);
        PointF controlPointF = new PointF(mControlPoint);

        //点击的点到控制旋转，缩放点的距离
        float distanceToControl = distance4PointF(touchPoint, controlPointF);

        //如果两者之间的距离小于 控制图标的宽度，高度的最小值，则认为点中了控制图标
        if (distanceToControl < Math.min(mControlDrawableWidth / 2, mControlDrawableHeight / 2)) {
            return STATUS_ROTATE_ZOOM;
        }

        float disToEdit = distance4PointF(touchPoint, new PointF(mEditPoint));
        if (disToEdit < Math.min(mEditDrawableWidth / 2, mEditDrawableHeight / 2)) {
            return STATUS_EDIT;
        }

        float disToDelete = distance4PointF(touchPoint, new PointF(mDeletePoint));
        if (disToDelete < Math.min(mDeleteDrawableWidth / 2, mDeleteDrawableHeight / 2)) {
            return STATUS_DELETE;
        }
        return STATUS_DRAG;

    }


    public float getImageRotate() {
        return mDegree;
    }

    public void setImageRotate(float degree) {
        if (this.mDegree != degree) {
            this.mDegree = degree;
            transformDraw();
        }
    }

    public float getImageScale() {
        return mScale;
    }

    public void setImageScale(float scale) {
        if (this.mScale != scale) {
            this.mScale = scale;
            transformDraw();
        }
    }


    public Drawable getmControlDrawable() {
        return mControlDrawable;
    }

    public void setControlDrawable(Drawable drawable) {
        this.mControlDrawable = drawable;
        mControlDrawableWidth = drawable.getIntrinsicWidth();
        mControlDrawableHeight = drawable.getIntrinsicHeight();
        transformDraw();
    }

    public int getFramePadding() {
        return mFramePadding;
    }

    public void setFramePadding(int mFramePadding) {
        if (this.mFramePadding == mFramePadding)
            return;
        this.mFramePadding = (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, mFramePadding, metrics);
        transformDraw();
    }

    public int getFrameColor() {
        return frameColor;
    }

    public void setFrameColor(int frameColor) {
        if (this.frameColor == frameColor)
            return;
        this.frameColor = frameColor;
        mPaint.setColor(frameColor);
        invalidate();
    }

    public int getFrameWidth() {
        return frameWidth;
    }

    public void setFrameWidth(int frameWidth) {
        if (this.frameWidth == frameWidth)
            return;
        this.frameWidth = (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, frameWidth, metrics);
        mPaint.setStrokeWidth(frameWidth);
        invalidate();
    }

    public void setmControlLocation(int location) {
        if (this.mControlLocation == location)
            return;
        this.mControlLocation = location;
        transformDraw();
    }

    public int getmControlLocation() {
        return mControlLocation;
    }


    public PointF getCenterPoint() {
        return mCenterPoint;
    }

    public void setCenterPoint(PointF mCenterPoint) {
        this.mCenterPoint = mCenterPoint;
        adjustLayout();
    }

    private float distance4PointF(PointF pf1, PointF pf2) {
        float disX = pf2.x - pf1.x;
        float disY = pf2.y - pf1.y;
        return (float) Math.sqrt(disX * disX + disY * disY);
    }


    public float getCenterX() {
        return mCenterPoint.x;
    }

    public float getCenterY() {
        return mCenterPoint.y;
    }

    private float mCenterX, mCenterY;

    public void setCenterX(float x) {
        mCenterX = x;
    }

    public void setCenterY(float y) {
        mCenterY = y;
    }

}