package com.jdcloud.media.demo.player;

import com.jdcloud.media.demo.MainActivity;
import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.base.BaseActivity;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.common.network.OkHttpUtil;
import com.jdcloud.media.demo.player.adapter.FragmentViewPagerAdapter;
import com.jdcloud.media.demo.player.bean.FloatVideoBean;
import com.jdcloud.media.demo.player.bean.LogBean;
import com.jdcloud.media.demo.player.bean.Result;
import com.jdcloud.media.demo.player.bean.Stream;
import com.jdcloud.media.demo.player.bean.VideoBean;
import com.jdcloud.media.demo.player.widget.JDPlayerView;
import com.jdcloud.media.demo.player.widget.MoreView;
import com.jdcloud.media.demo.utils.CommonUtils;
import com.jdcloud.media.demo.utils.LogUtil;
import com.jdcloud.media.demo.utils.SharePreferenceUtil;
import com.jdcloud.media.demo.utils.ToastUtil;
import com.jdcloud.media.player.jdcplayer.IMediaPlayer;
import com.jdcloud.media.player.wrapper.model.PlayerMonitor;

import android.app.AlertDialog;
import android.content.BroadcastReceiver;
import android.content.ComponentName;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Looper;
import android.support.design.widget.TabLayout;
import android.support.v4.view.ViewPager;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.WindowManager;
import android.widget.Button;
import android.widget.LinearLayout;
import android.widget.ProgressBar;
import android.widget.Toast;

import org.greenrobot.eventbus.EventBus;

import java.util.List;
import java.util.logging.Handler;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;


public class BasePlayerActivity extends BaseActivity implements JDPlayerView.PlayerViewCallback {

    private final static String TAG = BasePlayerActivity.class.getSimpleName();
    private TabLayout mTabLayout;
    private FragmentViewPagerAdapter mViewPageAdapter;
    private ViewPager mViewPager;
    @BindView(R.id.player_url_play)
    Button mBtnPlayUrl;
    @BindView(R.id.ll_player_content_list)
    LinearLayout mContentList;
    @BindView(R.id.jd_player_view)
    JDPlayerView mPlayerView;
    @BindView(R.id.mv_more_normal)
    MoreView mMoreView;
    @BindView(R.id.pb_loading)
    ProgressBar mLoading;

    private int mCurrentPlayMode;//悬浮窗，正常播放和全屏播放

    //    add by BLAY,记录当前播放类型(直播，点播，本地),方便标记正在播放的视频
    private int currentPlayType;//如Constant.PLAYER.TYPE_LIVE
    private MyRecerver homeRecerver;
    private boolean formHome = false;

    public void showMoreView() {
        mMoreView.initBackgroundUi(mPlayerView.getIsBackgroundPlay());
        mMoreView.updateMirrorUi(mPlayerView.getIsMirror());
        mMoreView.setVisibility(View.VISIBLE);
//        mBtnPlayUrl.setVisibility(View.GONE);
    }

    @OnClick(R.id.btn_player_hide_more)
    public void hideMoreView() {
        mMoreView.setVisibility(View.GONE);
//        mBtnPlayUrl.setVisibility(View.VISIBLE);
        mLoading.setVisibility(View.GONE);
    }

    @Override
    public void initView() {
        setContentView(R.layout.activity_base_player);
        ButterKnife.bind(this);

        mViewPager = findViewById(R.id.player_view_pager);
        mViewPager.setOffscreenPageLimit(3);
        mViewPageAdapter = new FragmentViewPagerAdapter(getSupportFragmentManager());
        mViewPager.setAdapter(mViewPageAdapter);
        mTabLayout = findViewById(R.id.player_tab_layout);
        mTabLayout.setupWithViewPager(mViewPager);
        mViewPager.setCurrentItem(0);

        mMoreView.setCallBack(mPlayerView);
    }

    @Override
    public void initData() {
        loadVideo();
        getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
    }

    private void loadVideo() {
        if (GlobalPlayer.INSTANCE.getInstance() != null) {
            //悬浮窗播放跳转而来
//            LogUtil.d("BLAY", "BasePlayerActivity:initData-----------GlobalPlayer.INSTANCE.getInstance() != null");
            mLoading.setVisibility(View.GONE);
            //悬浮窗播放时候，把播放信息临时放在mJDCloudVideoView中
            final FloatVideoBean floatVideoBean = (FloatVideoBean) GlobalPlayer.INSTANCE.getInstance().getTag();
            if (floatVideoBean == null) {
//              LogUtil.d("BLAY", "(VideoBean)GlobalPlayer.INSTANCE.getInstance().getTag()获取的floatVideoBean为空");
                return;
            }
            currentPlayType = floatVideoBean.getType();
            //调用顺序不能颠倒，否则可能获取不到视频初始化时长
            mPlayerView.addVideoView(GlobalPlayer.INSTANCE.getInstance());
            mPlayerView.setVideoBean(floatVideoBean.getVideoBean(), currentPlayType);
            //延时刷新界面
            new android.os.Handler(Looper.getMainLooper()).postDelayed(new Runnable() {
                @Override
                public void run() {
                    LogUtil.i("BLAY", "获取position:currentPlayType-------------" + floatVideoBean.getPosition() + "," + floatVideoBean.getType());
                    mViewPageAdapter.refreshUI(floatVideoBean.getPosition());
                    if (currentPlayType == Constant.PLAYER.TYPE_LIVE) {
                        mViewPager.setCurrentItem(0);
                    } else if (currentPlayType == Constant.PLAYER.TYPE_VOD) {
                        mViewPager.setCurrentItem(1);
                    } else if (currentPlayType == Constant.PLAYER.TYPE_LOCAL) {
                        mViewPager.setCurrentItem(2);
                    }

                }
            }, 400);
        } else {
            //点击首页的播放视频跳转而来(先初始化PlayerView,在view加载完毕后，播放第一个视频)
//            LogUtil.d("BLAY", "BasePlayerActivity:initData-----------GlobalPlayer.INSTANCE.getInstance() == null");
            GlobalPlayer.INSTANCE.initPlayer(this);
            mPlayerView.addVideoView(GlobalPlayer.INSTANCE.getInstance());
        }
    }

    public void playFirstVideo(VideoBean video) {
        if (mPlayerView.getVideoBean() != null)
            return;//在悬浮窗跳转而来，不需要重新播放
        if (video == null) {
            if (mViewPageAdapter.getFirstVideo() != null) {
                currentPlayType = mViewPageAdapter.getFirstVideoType();
                play(mViewPageAdapter.getFirstVideo(), true, currentPlayType);
            } else {
                LogUtil.d("BLAY", "BasePlayerActivity:mViewPageAdapter.getFirstVideo()未获取到视频");
                //延时播放第一个视频，防止没有初始化完
                new android.os.Handler(Looper.getMainLooper()).postDelayed(new Runnable() {
                    @Override
                    public void run() {
                        play(mViewPageAdapter.getFirstVideo(), true, currentPlayType);
                    }
                }, 500);
            }
        } else {
            play(video, true, Constant.PLAYER.TYPE_VOD);
            mViewPageAdapter.refreshUI(0);
            mViewPager.setCurrentItem(1);
        }
    }

    @Override
    protected void onNewIntent(Intent intent) {
        LogUtil.d("BLAY", "BasePlayerActivity:onNewIntent");
        super.onNewIntent(intent);
        VideoBean vb = new VideoBean();
        vb.setVideoURL(intent.getStringExtra(Constant.PLAY_URL));
        urlPlay(vb);
    }

    @OnClick(R.id.iv_controller_back)
    public void backToFloat() {
//        mPlayerView.removeVideoView(GlobalPlayer.INSTANCE.getInstance());
//        LogUtil.d(TAG, "current play status is " + mPlayerView.getPlayState());
        if (GlobalPlayer.INSTANCE.getInstance() != null) {
            if (!GlobalPlayer.INSTANCE.getInstance().isPlaying()) {
                GlobalPlayer.INSTANCE.destroy();
            } else {
                //需要保存播放的视频信息,以便悬浮窗播放
                int position = mViewPageAdapter.getSelect(currentPlayType);
                if (mPlayerView.getVideoBean() != null && GlobalPlayer.INSTANCE.getInstance().isPlaying()) {
                    FloatVideoBean floatBean = new FloatVideoBean(mPlayerView.getVideoBean(), currentPlayType, position);
                    LogUtil.i("BLAY", "保存position:currentPlayType-------------" + position + "," + currentPlayType);
                    GlobalPlayer.INSTANCE.getInstance().setTag(floatBean);
                }
                GlobalPlayer.INSTANCE.getInstance().pause();
//                mCurrentPlayMode = Constant.PLAYER.PLAY_MODE_FLOAT;
            }
        }
        finish();
//        Intent intent=new Intent(this,MainActivity.class);
//        startActivity(intent);
    }

    @OnClick(R.id.player_url_play)
    public void goUrlPlay() {
        startComponent(PlayerUrlActivity.class);
    }

    @Override
    public void onBackPressed() {
        if (mPlayerView.getPlayMode() == Constant.PLAYER.PLAY_MODE_NORMAL) {
            backToFloat();
        } else {
//            mPlayerView.requestPlayMode(Constant.PLAYER.PLAY_MODE_NORMAL);
            mPlayerView.onBackPressed();
        }
    }

    private void urlPlay(VideoBean vb) {
        play(vb, false, Constant.PLAYER.TYPE_URL);
    }

    public void play(VideoBean vb, boolean isFirstPlay, int type) {
        currentPlayType = type;
        mPlayerView.play(vb, isFirstPlay, type);
        mViewPageAdapter.refreshUI(-1);

        Log.e("BLAY", "播放视频：" + vb.getVideoURL() + " name is " + vb.getName() + " image is  " + vb.getHolderImage());
        LogBean bean = new LogBean();
        bean.setLog("clear");
        bean.setTime("clear");
        EventBus.getDefault().post(bean);
    }

    @Override
    public void initListener() {
        mViewPager.addOnPageChangeListener(new TabLayout.TabLayoutOnPageChangeListener(mTabLayout) {
            @Override
            public void onPageSelected(int position) {
                if (position == 0 || position == 1) {
                    mBtnPlayUrl.setVisibility(View.VISIBLE);
                } else {
                    mBtnPlayUrl.setVisibility(View.GONE);
                }
                super.onPageSelected(position);
            }
        });
        mPlayerView.setPlayerViewCallback(this);
        mLoading.setVisibility(View.GONE);
        GlobalPlayer.INSTANCE.getInstance().setOnPreparedListener(new IMediaPlayer.OnPreparedListener() {
            @Override
            public void onPrepared(IMediaPlayer iMediaPlayer) {
                JDPlayerView.PLAY_STATE = Constant.PLAYER.PREPARED;
                mPlayerView.updatePlayStatus(false);
            }
        });
        GlobalPlayer.INSTANCE.getInstance().setOnCompletionListener(new IMediaPlayer.OnCompletionListener() {
            @Override
            public void onCompletion(IMediaPlayer iMediaPlayer) {
                JDPlayerView.PLAY_STATE = Constant.PLAYER.COMPLETED;
                mPlayerView.updatePlayStatus(false);
            }
        });
        GlobalPlayer.INSTANCE.getInstance().setOnInfoListener(new IMediaPlayer.OnInfoListener() {
            @Override
            public boolean onInfo(IMediaPlayer iMediaPlayer, int i, int infoIndex) {
                switch (i) {
                    case IMediaPlayer.MEDIA_INFO_VIDEO_RENDERING_START:
                        //加载第一帧完成，每次切换视频都会回调
                        JDPlayerView.PLAY_STATE = Constant.PLAYER.STARTED;
//                        LogUtil.d("BLAY", " 收到消息： " + "MEDIA_INFO_VIDEO_RENDERING_START " );
                        mPlayerView.updatePlayStatus(true);
                        sendLog();
                        break;
                    case IMediaPlayer.MEDIA_INFO_BUFFERING_START:
//                        LogUtil.d("BLAY", " 收到消息： " + "MEDIA_INFO_BUFFERING_START " );
                        //开始缓冲，视频可以加载进度条，以前段拖动完毕为准
                        break;
                    case IMediaPlayer.MEDIA_INFO_BUFFERING_END:
//                        LogUtil.d("BLAY", " 收到消息： " + "MEDIA_INFO_BUFFERING_END " );
//                        JDPlayerView.PLAY_STATE = Constant.PLAYER.STARTED;
                        //缓冲完成，可能会发生在视频刚加载，拖动进度条或者网路不好的情况
                        break;
                    case IMediaPlayer.MEDIA_INFO_VIDEO_SEEK_RENDERING_START:
//                        LogUtil.d("BLAY", " 收到消息： " + "MEDIA_INFO_MEDIA_ACCURATE_SEEK_COMPLETE " );
                        JDPlayerView.PLAY_STATE = Constant.PLAYER.STARTED;
                        //seek完成后加载视频
                        mPlayerView.updatePlayStatus(true);
                        break;
                    default:
                        break;
                }
//                LogUtil.d(TAG, "player onInfo " + mLog + " infoIndex is " + i);
                return true;
            }
        });
        GlobalPlayer.INSTANCE.getInstance().setOnErrorListener(new IMediaPlayer.OnErrorListener() {
            @Override
            public boolean onError(IMediaPlayer iMediaPlayer, int i, int errorIndex) {
//                mTime = CommonUtils.timeFormat();
                JDPlayerView.PLAY_STATE = Constant.PLAYER.ERROR;
                mPlayerView.updatePlayStatus(false);
                if (i == -10000) {
                    if (errorIndex == IMediaPlayer.MEDIA_ERROR_NO_NETWORK) {
                        ToastUtil.makeText(BasePlayerActivity.this, "视频加载失败，请稍后重试。", Toast.LENGTH_SHORT);
                    } else if (errorIndex == IMediaPlayer.MEDIA_ERROR_INVALID_URL) {
                        ToastUtil.makeText(BasePlayerActivity.this, "文件不存在或者已被删除。", Toast.LENGTH_SHORT);
                    } else if (errorIndex == IMediaPlayer.MEDIA_ERROR_MEDIAFORMAT_UNSUPPORTED) {
                        ToastUtil.makeText(BasePlayerActivity.this, "不支持的视频格式。", Toast.LENGTH_SHORT);
                    } else if (errorIndex == IMediaPlayer.MEDIA_ERROR_TIMED_OUT) {
                        ToastUtil.makeText(BasePlayerActivity.this, "视频加载超时。", Toast.LENGTH_SHORT);
                    } else {
                        ToastUtil.makeText(BasePlayerActivity.this, "播放器返回错误", Toast.LENGTH_SHORT);
                    }
                }
//                sendEvent();
                return true;
            }
        });
        //注册home监听
        homeRecerver = new MyRecerver();
        IntentFilter filter = new IntentFilter(Intent.ACTION_CLOSE_SYSTEM_DIALOGS);
        registerReceiver(homeRecerver, filter);
    }

    @Override
    public void onResume() {
        super.onResume();
        if (mPlayerView != null) {
            mPlayerView.onResume();
            mCurrentPlayMode = mPlayerView.getPlayMode();
        } else {
//            loadVideo();
        }
    }

    @Override
    public void onPause() {
        mPlayerView.pauseGifPlayer();
        if (GlobalPlayer.INSTANCE.getInstance() != null && GlobalPlayer.INSTANCE.getInstance().isPlaying()) {
            if (formHome) {
                if (!mPlayerView.getIsBackgroundPlay()) {
                    mPlayerView.onPause(true);
                }
            } else {
                mPlayerView.onPause(true);
            }
            LogUtil.d("BLAY", "BasePlayerActivity-----------onPause");
        }
        super.onPause();
    }

    @Override
    public void hideViews() {
        mContentList.setVisibility(View.GONE);
        if (mMoreView.getVisibility() == View.VISIBLE) {
            mMoreView.setVisibility(View.GONE);
        }
    }

    @Override
    public void showViews() {
        mContentList.setVisibility(View.VISIBLE);
    }


    @Override
    protected void onDestroy() {
        super.onDestroy();
        unregisterReceiver(homeRecerver);
        LogUtil.e("BLAY", "BasePlayerActivity:onDestroy");
        OkHttpUtil.getInstance().cancelAll();
    }

    public int getCurrentPlayType() {
        return currentPlayType;
    }


    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == 100) {
            //处理gif截屏返回
            mPlayerView.getHandler().sendEmptyMessage(997);
        }
        super.onActivityResult(requestCode, resultCode, data);
    }

    public void playNextVideo() {
        if (currentPlayType == Constant.PLAYER.TYPE_URL) {
            ToastUtil.makeText(this, "已是最后一个视频", Toast.LENGTH_SHORT);
            return;
        }
        VideoBean video = mViewPageAdapter.getNextVideo(currentPlayType, true);
        if (video != null) {
            play(video, false, currentPlayType);
        } else {
            ToastUtil.makeText(this, "已是最后一个视频", Toast.LENGTH_SHORT);
        }
    }

    public VideoBean getNextVideo() {
        return mViewPageAdapter.getNextVideo(currentPlayType, false);
    }

    class MyRecerver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {
            LogUtil.d("BLAY", "BasePlayerActivity-----------onReceive");
//            if (mCurrentPlayMode != Constant.PLAYER.PLAY_MODE_FLOAT) {
            formHome = true;
            mPlayerView.pauseGifPlayer();
            if (!mPlayerView.getIsBackgroundPlay()) {
                mPlayerView.onPause(true);
            }
//            }
        }
    }

    public void sendLog() {
        PlayerMonitor monitor = mPlayerView.getPlayerMonitor();
        String vdec = monitor.getVdec() + "";
        if (!TextUtils.isEmpty(vdec)) {
            LogBean bean = new LogBean();
            if ("1".equals(vdec)) {
                bean.setLog("vdec:硬解");
            } else if ("2".equals(vdec)) {
                bean.setLog("vdec:软解");
            }
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }

        String remoteIp = monitor.getRemoteIp();
        if (!TextUtils.isEmpty(remoteIp)) {
            LogBean bean = new LogBean();
            bean.setLog("remoteIp:" + remoteIp);
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }

        String bitRate = monitor.getBitRate() + "";
        if (!TextUtils.isEmpty(bitRate)) {
            LogBean bean = new LogBean();
            bean.setLog("bitRate:" + bitRate);
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }

        String dnsDuration = monitor.getDnsParseDuration() + "";
        if (!TextUtils.isEmpty(dnsDuration)) {
            LogBean bean = new LogBean();
            bean.setLog("dnsDuration:" + dnsDuration);
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }

        String prepareDuration = monitor.getPrepareDuration() + "";
        if (!TextUtils.isEmpty(prepareDuration)) {
            LogBean bean = new LogBean();
            bean.setLog("prepareDuration:" + prepareDuration);
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }

        String firstVideoFrameLatency = monitor.getFirstVideoFrameLatency() + "";
        if (!TextUtils.isEmpty(firstVideoFrameLatency)) {
            LogBean bean = new LogBean();
            bean.setLog("firstVideoFrameLatency:" + firstVideoFrameLatency);
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }

        String videoDecoder = monitor.getVideoDecoder();
        if (!TextUtils.isEmpty(firstVideoFrameLatency)) {
            LogBean bean = new LogBean();
            bean.setLog("videoDecoder:" + videoDecoder);
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }
        if (monitor.getVideoWidth() != 0) {
            LogBean bean = new LogBean();
            bean.setLog("width:" + monitor.getVideoWidth() + ",height:" + monitor.getVideoHeight());
            bean.setTime(CommonUtils.timeFormat());
            EventBus.getDefault().post(bean);
        }

    }
}
