package com.jdcloud.media.demo.player;

import android.Manifest;
import android.content.Context;
import android.content.Intent;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.text.TextUtils;
import android.view.MotionEvent;
import android.view.View;
import android.widget.EditText;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.base.BaseActivity;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.common.QRCodeScannerActivity;
import com.jdcloud.media.demo.utils.PermissionUtils;
import com.jdcloud.media.demo.utils.ToastUtil;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class PlayerUrlActivity extends BaseActivity {
    @BindView(R.id.action_bar_back)
    RelativeLayout mBack;
    @BindView(R.id.action_bar_title)
    TextView mTitle;
    @BindView(R.id.et_player_url)
    EditText mEditText;

    private Context mContext;

    @Override
    public void initView() {
        setContentView(R.layout.activity_player_url);
        ButterKnife.bind(this);
        mContext = this;
    }

    @Override
    public void initData() {

    }

    @Override
    public void setActionBar() {
        mBack.setVisibility(View.VISIBLE);
        mTitle.setText(R.string.return_play_list);
    }

    @OnClick(R.id.action_bar_back)
    public void backPlayList() {
        onBackPressed();
    }

    @OnClick(R.id.btn_player_url_play)
    public void playUrlVideo() {
        if (TextUtils.isEmpty(mEditText.getText())) {
            ToastUtil.makeText(mContext, R.string.player_url_hint, Toast.LENGTH_LONG);
        } else {
            Intent i = new Intent(this, BasePlayerActivity.class);
            i.putExtra(Constant.PLAY_URL, mEditText.getText().toString());
            startActivity(i);
        }
    }

    @Override
    public void initListener() {
        mEditText.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                Drawable drawable = mEditText.getCompoundDrawables()[2];
                if (drawable == null) {
                    return false;
                }
                if (event.getAction() != MotionEvent.ACTION_UP) {
                    return false;
                }
                if (event.getX() > mEditText.getWidth() - mEditText.getPaddingRight() - drawable.getIntrinsicWidth()) {
                    if (!PermissionUtils.checkPermission(mContext, Manifest.permission.CAMERA)) {
                        // 申请权限
                        PermissionUtils.requestPermissions(PlayerUrlActivity.this, new String[]{Manifest.permission.CAMERA}, 100);
                        return false;
                    }
                    Intent i = new Intent(mContext, QRCodeScannerActivity.class);
                    startActivityForResult(i, Constant.SCAN_PLAY_URL_REQUEST);
                }
                return false;
            }
        });
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        if (requestCode == Constant.SCAN_PLAY_URL_REQUEST && resultCode == RESULT_OK) {
            Bundle bundle = data.getExtras();
            String scanResult = bundle.getString(QRCodeScannerActivity.SCAN_RESULT);
            mEditText.setText(scanResult);
        }
    }

}
