package com.jdcloud.media.demo.player.adapter;


import android.support.v4.app.Fragment;
import android.support.v4.app.FragmentManager;
import android.support.v4.app.FragmentStatePagerAdapter;

import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.player.bean.VideoBean;
import com.jdcloud.media.demo.player.cotent.LiveListFragment;
import com.jdcloud.media.demo.player.cotent.LocalListFragment;
import com.jdcloud.media.demo.player.cotent.LogListFragment;
import com.jdcloud.media.demo.player.cotent.VodListFragment;
import com.jdcloud.media.demo.utils.LogUtil;

public class FragmentViewPagerAdapter extends FragmentStatePagerAdapter {

    private static String[] TAB_TITLE = {"直播", "点播", "本地", "日志"};
    private FragmentManager fragmentManager;
    public FragmentViewPagerAdapter(FragmentManager fm) {
        super(fm);
        this.fragmentManager=fm;
    }
    private int firstVideoType;
    @Override
    public CharSequence getPageTitle(int position) {
        return TAB_TITLE[position];
    }

    @Override
    public Fragment getItem(int position) {
        switch (position) {
            case 0:
                return new LiveListFragment();
            case 1:
                return new VodListFragment();
            case 2:
                return new LocalListFragment();
            case 3:
                return new LogListFragment();
            default:
                return new VodListFragment();
        }
    }

    @Override
    public int getCount() {
        return TAB_TITLE.length;
    }

    /**
     * 每次播放都要刷新所有fragment，保证只有一条视频是正在播放的状态
     * @param position 选中的position（-1表示没有选中）
     */
    public void refreshUI(int position){
        if(fragmentManager==null ){
            return;
        }
        for(Fragment fragment:fragmentManager.getFragments()){
            if(fragment instanceof LiveListFragment){
//                LogUtil.i("BLAY","setSelect:LiveListFragment:position-------------"+position);
                ((LiveListFragment) fragment).refreshUI(position);
            }
            if(fragment instanceof VodListFragment){
                ((VodListFragment)fragment).refreshUI(position);
            }
            if(fragment instanceof LocalListFragment){
                ((LocalListFragment)fragment).refreshUI(position);
            }
        }
    }

    public VideoBean getFirstVideo(){
        VideoBean bean=null;
        for(Fragment fragment:fragmentManager.getFragments()){
            if(fragment instanceof LiveListFragment ){
                bean=((LiveListFragment)fragment).getFirstVideo();
                firstVideoType=Constant.PLAYER.TYPE_LIVE;
            }
            if(fragment instanceof VodListFragment && bean==null ){
                bean=((VodListFragment)fragment).getFirstVideo();
                firstVideoType=Constant.PLAYER.TYPE_VOD;
            }
            if(fragment instanceof LocalListFragment && bean==null){
                bean=((LocalListFragment)fragment).getFirstVideo();
                firstVideoType=Constant.PLAYER.TYPE_LOCAL;
            }

        }
        return bean;
    }
    public int getFirstVideoType(){
        return firstVideoType;
    }

    /**
     * @param videoType  获取当前类型的下一个视频
     * @param needPlay 获取后随机播放，true时视频需要显示为选中状态
     * @return
     */
    public VideoBean getNextVideo(int videoType,boolean needPlay){
        VideoBean bean=null;
        for(Fragment fragment:fragmentManager.getFragments()){
            if(fragment instanceof LiveListFragment && videoType==Constant.PLAYER.TYPE_LIVE){
                bean=((LiveListFragment)fragment).getNextVideo(needPlay);
                break;
            }
            if(fragment instanceof VodListFragment && videoType==Constant.PLAYER.TYPE_VOD){
                bean=((VodListFragment)fragment).getNextVideo(needPlay);
                break;
            }
            if(fragment instanceof LocalListFragment && videoType==Constant.PLAYER.TYPE_LOCAL){
                bean=((LocalListFragment)fragment).getNextVideo(needPlay);
            }
        }
        return bean;
    }

    public int getSelect(int videoType){
        int position=-1;
        for(Fragment fragment:fragmentManager.getFragments()){
            if(fragment instanceof LiveListFragment && videoType==Constant.PLAYER.TYPE_LIVE){
                position=((LiveListFragment) fragment).getSelect();
                break;
            }
            if(fragment instanceof VodListFragment && videoType==Constant.PLAYER.TYPE_VOD){
                position=((VodListFragment)fragment).getSelect();
                break;
            }
            if(fragment instanceof LocalListFragment && videoType==Constant.PLAYER.TYPE_LOCAL){
                position=((LocalListFragment)fragment).getSelect();
            }
        }
        return position;
    }
}
