package com.jdcloud.media.demo.player.adapter;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.player.bean.LogBean;
import java.util.List;

public class LogAdapter extends RecyclerView.Adapter<LogAdapter.LogHolder> {

    private Context mContext;
    private OnItemClickListener mListener;
    private List<LogBean> mDataList;

    public LogAdapter(Context context, List<LogBean> dataList) {

        this.mContext = context;
        this.mDataList = dataList;
    }

    public void updateData(List<LogBean> data) {
        this.mDataList = data;
        notifyDataSetChanged();
    }

    public void setClickListener(OnItemClickListener listener) {
        this.mListener = listener;
    }

    @Override
    public LogHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View v = LayoutInflater.from(parent.getContext()).inflate(R.layout.layout_player_log_item, parent, false);
        LogHolder ah = new LogHolder(v);
        ah.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mListener != null) {
                    mListener.onItemClick(v);
                }
            }
        });
        return ah;
    }

    @Override
    public void onBindViewHolder(LogHolder holder, int position) {
        LogBean data = null;
        if (mDataList != null) {
            data = mDataList.get(position);
        }

        if (data != null) {
            holder.mLogInfo.setText(data.getLog());
            holder.mLogTime.setText(data.getTime());
        }
    }

    @Override
    public int getItemCount() {
        if (mDataList != null) {
            return mDataList.size();
        }
        return 0;
    }

    class LogHolder extends RecyclerView.ViewHolder {
        private TextView mLogTime;
        private TextView mLogInfo;

        public LogHolder(View itemView) {
            super(itemView);
            mLogTime = itemView.findViewById(R.id.tv_log_time);
            mLogInfo = itemView.findViewById(R.id.tv_log_info);
        }
    }

    public interface OnItemClickListener {
        void onItemClick(View view);
    }
}
