package com.jdcloud.media.demo.player.adapter;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.engine.DiskCacheStrategy;
import com.bumptech.glide.request.RequestOptions;
import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.base.BaseActivity;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.player.BasePlayerActivity;
import com.jdcloud.media.demo.player.bean.LocalVideo;
import com.jdcloud.media.demo.player.bean.Result;
import com.jdcloud.media.demo.player.bean.VideoBean;
import com.jdcloud.media.demo.utils.CommonUtils;
import com.jdcloud.media.demo.utils.LogUtil;

import java.io.File;
import java.util.List;

public class VideoAdapter extends RecyclerView.Adapter<VideoAdapter.VodHolder> {

    private Context mContext;
    private OnItemClickListener mListener;
    private List<? extends VideoBean> mDataList;
    private int mVideoTag;//视频的类型 如：Constant.PLAYER.TYPE_LOCAL
    private int mSelectedPosition = -1;

    public int getVideoTag() {
        return mVideoTag;
    }

    public VideoAdapter(Context context, List<? extends VideoBean> dataList ,int tag) {
        this.mContext = context;
        this.mDataList = dataList;
        this.mVideoTag=tag;

        new Thread(new Runnable() {
            @Override
            public void run() {
                //连续录屏会导致视频封面没变化，清理磁盘缓存
                Glide.get(mContext).clearDiskCache();
            }
        }).start();

    }

//    public void updateData(List<? extends VideoBean> data, int tag) {
//        this.mDataList = data;
//        this.mVideoTag = tag;
//        notifyDataSetChanged();
//    }

    public void setClickListener(OnItemClickListener listener) {
        this.mListener = listener;
    }

    @Override
    public VodHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View v = LayoutInflater.from(parent.getContext()).inflate(R.layout.layout_player_vod_item, parent, false);
        VodHolder ah = new VodHolder(v);
        return ah;
    }

    public void updateSelectPosition(int position) {
        if(position!=-1){
            this.mSelectedPosition = position;
        }
//        LogUtil.i("BLAY","updateSelectPosition:notifyDataSetChanged-------------"+position);
        notifyDataSetChanged();
    }
    public int getSelectedPosition(){
        return mSelectedPosition;
    }

    @Override
    public void onBindViewHolder(VodHolder holder, final int position) {
        VideoBean data = null;
        if (mDataList != null) {
            data = mDataList.get(position);
        }
        if (mSelectedPosition == position && ((BasePlayerActivity)mContext).getCurrentPlayType()==mVideoTag) {
            holder.mTitleTV.setTextColor(mContext.getResources().getColor(R.color.common_btn_selected_color));
        } else {
            holder.mTitleTV.setTextColor(mContext.getResources().getColor(R.color.white));
        }
        holder.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mListener != null) {
                    mListener.onItemClick(v);
                }
            }
        });
        if (data != null) {
//            LogUtil.d("BLAY","data.video_type:"+data.video_type);
//            LogUtil.d("BLAY","mVideoTag::"+mVideoTag);
            if (data instanceof LocalVideo) {
                LocalVideo lv = (LocalVideo) data;
                Glide.with(mContext).load(new File(lv.getPath())).into(holder.mImage);
                holder.mTitleTV.setText(lv.getName());
                holder.mDurationTV.setText(CommonUtils.formattedTime(lv.getDuration()));
            } else if (data instanceof Result) {
                Glide.with(mContext).load(((Result) data).getImgUrl()).into(holder.mImage);
                holder.mTitleTV.setText(((Result) data).getName());
                if(mVideoTag==Constant.PLAYER.TYPE_LIVE){
                    holder.mDurationTV.setText("");
                }else {
//                    holder.mDurationTV.setText(String.valueOf(((Result) data).getDuration()));
                    holder.mDurationTV.setText(CommonUtils.formattedTime(((Result) data).getPlayTime()*1000));
                }
            } else {
                Glide.with(mContext).load(data.getHolderImage()).into(holder.mImage);
                holder.mTitleTV.setText(data.getName());
                if(mVideoTag==Constant.PLAYER.TYPE_VOD){
                    holder.mDurationTV.setText(CommonUtils.formattedTime(data.getTime()));
                }else{
                    holder.mDurationTV.setText("");
                }
            }
        }
    }

    @Override
    public int getItemCount() {
        if (mDataList != null) {
            return mDataList.size();
        }
        return 0;
    }

    class VodHolder extends RecyclerView.ViewHolder {
        private ImageView mImage;
        private TextView mTitleTV;
        private TextView mDurationTV;

        public VodHolder(View itemView) {
            super(itemView);
            mTitleTV = itemView.findViewById(R.id.tv_vod_name);
            mDurationTV = itemView.findViewById(R.id.tv_vod_duration);
            mImage = itemView.findViewById(R.id.iv_vod_image);
        }
    }

    public interface OnItemClickListener {
        void onItemClick(View view);
    }
}
