package com.jdcloud.media.demo.player.cotent;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.View;
import android.widget.Button;
import android.widget.ProgressBar;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.common.network.BaseResponse;
import com.jdcloud.media.demo.common.network.HttpRequest;
import com.jdcloud.media.demo.common.network.OkHttpUtil;
import com.jdcloud.media.demo.common.network.ResponseCallback;
import com.jdcloud.media.demo.common.view.CustomDialog;
import com.jdcloud.media.demo.player.BasePlayerActivity;
import com.jdcloud.media.demo.player.adapter.VideoAdapter;
import com.jdcloud.media.demo.player.bean.Result;
import com.jdcloud.media.demo.player.bean.Stream;
import com.jdcloud.media.demo.player.bean.VideoBean;
import com.jdcloud.media.demo.utils.LogUtil;
import com.jdcloud.media.demo.utils.ToastUtil;

import java.util.ArrayList;
import java.util.List;


public class VodListFragment extends BaseFragment {

    private static final String TAG = VodListFragment.class.getSimpleName();
    private List<VideoBean> mList = new ArrayList();
    RecyclerView mVodListRV;
    RelativeLayout rlRetry;
    ProgressBar pb_request;
    TextView tvRetry;

    private VideoAdapter mAdapter;
//    private List<VideoBean> mVodList = new ArrayList<>();


    @Override
    public int getLayoutId() {
        return R.layout.fragment_vod_list;
    }

    @Override
    public void initData() {
        mVodListRV.setLayoutManager(new LinearLayoutManager(getMyActivity(), LinearLayoutManager.VERTICAL, false));
        mAdapter = new VideoAdapter(getMyActivity(), mList, Constant.PLAYER.TYPE_VOD);
        mVodListRV.setAdapter(mAdapter);
        requestData();
    }

    private void requestData() {
        mVodListRV.setVisibility(View.GONE);
        rlRetry.setVisibility(View.VISIBLE);
        pb_request.setVisibility(View.VISIBLE);
        tvRetry.setVisibility(View.GONE);
        if (!OkHttpUtil.checkConnect(getContext())) {
            rlRetry.setVisibility(View.VISIBLE);
            pb_request.setVisibility(View.GONE);
            tvRetry.setVisibility(View.VISIBLE);
            mVodListRV.setVisibility(View.GONE);
            ((BasePlayerActivity) getActivity()).playFirstVideo(null);
            return;
        }
        OkHttpUtil.getInstance().doRequest(Constant.REQUEST_URL_VOD, "vod", null, HttpRequest.Method.GET, new ResponseCallback<BaseResponse>() {
            @Override
            public void onSuccess(BaseResponse baseResponse) {
                pb_request.setVisibility(View.GONE);
                rlRetry.setVisibility(View.GONE);
                if (baseResponse != null && baseResponse.getResult() != null) {
                    LogUtil.e("OkHttpUtil","URL："+Constant.REQUEST_URL_VOD+"\nbaseResponse:"+baseResponse.toString());

                    if (mList.size() > 0) {
                        mList.clear();
                    }
                    mList.addAll(baseResponse.getResult());
                    mAdapter.notifyDataSetChanged();
                    mVodListRV.setVisibility(View.VISIBLE);
                } else {
                    ToastUtil.makeText(getActivity(), "vod未请求到数据", Toast.LENGTH_SHORT);
                }
                if (mList.get(0) != null) {
                    playFirst();
                } else {
                    ((BasePlayerActivity) getActivity()).playFirstVideo(null);
                }
            }

            @Override
            public void onError(String tag, int errorCode) {
//                ToastUtil.makeText(getActivity(),tag+"------请求失败",Toast.LENGTH_SHORT);
//                loadVideo();
                rlRetry.setVisibility(View.VISIBLE);
                pb_request.setVisibility(View.GONE);
                tvRetry.setVisibility(View.VISIBLE);
                mVodListRV.setVisibility(View.GONE);
                ((BasePlayerActivity) getActivity()).playFirstVideo(null);
            }
        });
    }

    private void playFirst() {
        if (OkHttpUtil.checkConnect(getContext())) {
            if (OkHttpUtil.isWifi(getContext())) {
                //wifi播放
                ((BasePlayerActivity) getActivity()).playFirstVideo(mList.get(0));
            } else {
                //非wifi需要用户确认后再播放
                AlertDialog.Builder builder = new AlertDialog.Builder(getContext());
                builder.setTitle("提示信息").setMessage("当前网络环境不是WIFI，是否继续播放?").setPositiveButton("继续", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        // TODO Auto-generated method stub
                        ((BasePlayerActivity) getActivity()).playFirstVideo(mList.get(0));
                    }
                }).setNegativeButton("取消", new DialogInterface.OnClickListener() {

                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        // TODO Auto-generated method stub
                        dialog.dismiss();
                    }
                }).setCancelable(false).show();
            }
        }
    }


    @Override
    public void initViews() {
        mVodListRV = mView.findViewById(R.id.rv_vod_list);
        rlRetry = mView.findViewById(R.id.rlRetry);
        pb_request = mView.findViewById(R.id.pb_request);
        tvRetry = mView.findViewById(R.id.tvRetry);
    }

    @Override
    public void initListener() {
        mAdapter.setClickListener(new VideoAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(View view) {
                final int position = mVodListRV.getChildAdapterPosition(view);
                final VideoBean bean = (mList.get(position));
                if (OkHttpUtil.checkConnect(getContext())) {
                    if (OkHttpUtil.isWifi(getContext())) {
                        //wifi播放
//                        int position = mVodListRV.getChildAdapterPosition(view);
                        mAdapter.updateSelectPosition(position);
                        getMyActivity().play(bean, false, Constant.PLAYER.TYPE_VOD);
                    } else {
                        //非wifi需要用户确认后再播放
                        AlertDialog.Builder builder = new AlertDialog.Builder(getContext());
                        builder.setTitle("提示信息").setMessage("当前网络环境不是WIFI，是否继续播放?").setPositiveButton("继续", new DialogInterface.OnClickListener() {
                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                // TODO Auto-generated method stub
                                mAdapter.updateSelectPosition(position);
                                getMyActivity().play(bean, false, Constant.PLAYER.TYPE_VOD);
                            }
                        }).setNegativeButton("取消", new DialogInterface.OnClickListener() {

                            @Override
                            public void onClick(DialogInterface dialog, int which) {
                                // TODO Auto-generated method stub
                                dialog.dismiss();
                            }
                        }).setCancelable(false).show();

//                        CustomDialog mBackDialog = new CustomDialog.Builder(getContext()).setTitle(R.string.player_network_tip_title).setContent(R.string.player_network_tip)
//                                .setOkBtn(R.string.player_network_continue).setCancelBtn(R.string.dialog_exit_cancel).setOkListener(
//                                        new View.OnClickListener() {
//                                            @Override
//                                            public void onClick(View v) {
//                                                mAdapter.updateSelectPosition(position);
//                                                getMyActivity().play(bean, false, Constant.PLAYER.TYPE_VOD);
//                                            }
//                                        }
//                                ).setCancelListener(new View.OnClickListener() {
//                                    @Override
//                                    public void onClick(View v) {
////                                        mBackDialog.dismiss();
//                                    }
//                                }).createDialog();
//                        mBackDialog.show();

                    }
                }
            }
        });
        rlRetry.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                requestData();
            }
        });
    }

    @Override
    public void onDestroyView() {
        super.onDestroyView();
        OkHttpUtil.getInstance().cancelTag("vod");
    }

    public VideoBean getFirstVideo() {
        if (mList != null && mList.size() > 0) {
            mAdapter.updateSelectPosition(0);
            return (mList.get(0));
        }
        return null;
    }

    public VideoBean getNextVideo(boolean needPlay) {
        if (mList != null && mList.size() > 0) {
            int nextPos = mAdapter.getSelectedPosition() + 1;
            if (nextPos != mAdapter.getItemCount()) {
                if(needPlay){
                    mAdapter.updateSelectPosition(nextPos);
                }
                return (mList.get(nextPos));
            }
        }
        return null;
    }

    public int getSelect() {
        return mAdapter.getSelectedPosition();
    }

    public void refreshUI(int position) {
        if (mAdapter != null) {
            mAdapter.updateSelectPosition(position);
        }
    }

}
