package com.jdcloud.media.demo.player.cotroller;

import android.content.Context;
import android.graphics.RectF;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.MediaController;
import android.widget.ProgressBar;
import android.widget.RelativeLayout;
import android.widget.SeekBar;
import android.widget.TextView;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.player.bean.VideoBean;
import com.jdcloud.media.demo.player.widget.JDPlayerView;
import com.jdcloud.media.demo.utils.CommonUtils;
import com.jdcloud.media.demo.utils.LogUtil;
import com.jdcloud.media.player.jdcplayer.IMediaPlayer;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

//正常播放界面
public class JDCMediaController extends JDCMediaControllerBase {

    @BindView(R.id.rl_controller_top)
    RelativeLayout mLayoutTop;
    @BindView(R.id.ll_controller_bottom)
    LinearLayout mLayoutBottom;
    @BindView(R.id.iv_controller_play)
    ImageView mIvPause;
    @BindView(R.id.iv_controller_enlarge)
    ImageView mIvFullScreen;
    @BindView(R.id.tv_controller_title)
    TextView mTvTitle;
    @BindView(R.id.tv_controller_current)
    TextView mTvCurrent;
    @BindView(R.id.tv_controller_duration)
    TextView mTvDuration;
    @BindView(R.id.sb_controller)
    SeekBar mSeekBarProgress;
    @BindView(R.id.pb_controller_normal)
    ProgressBar pb_controller_normal;//加载视频的进度条


    public JDCMediaController(@NonNull Context context) {
        super(context);
        initView();
    }

    public JDCMediaController(@NonNull Context context, @Nullable AttributeSet attributes) {
        super(context, attributes);
        initView();
    }

    private void initView() {
        mLayoutInflater.inflate(R.layout.layout_controller_normal, this);
        ButterKnife.bind(this);
        mProgress = findViewById(R.id.cpb_controller_normal);
        tvTimeToast = findViewById(R.id.tvTimeToast);
        mSeekBarProgress.setOnSeekBarChangeListener(this);
    }

    public void updateVideoProgress(int mPlayType, long current) {
        if (JDPlayerView.PLAY_STATE == Constant.PLAYER.IDLE) {
            if (mTvCurrent != null) mTvCurrent.setText(CommonUtils.formattedTime(current));
            if (mTvDuration != null) mTvDuration.setText(CommonUtils.formattedTime(0));
            mSeekBarProgress.setProgress(0);
            return;
        }

        if (mTvCurrent != null) mTvCurrent.setText(CommonUtils.formattedTime(current));
        if (tvTimeToast.getVisibility() != VISIBLE) {
            float percentage = duration > 0 ? (float) (current * 1.0 / duration) : 0f;
            if (percentage >= 0 && percentage <= 1) {
                if (mSeekBarProgress != null && mPlayType != Constant.PLAYER.TYPE_LIVE) {
                    int progress = Math.round(percentage * mSeekBarProgress.getMax());
                    mSeekBarProgress.setProgress(progress);
                }
                if(mTvDuration.getText().equals("00:00:00")){
                    mTvDuration.setText(CommonUtils.formattedTime(duration));
                }
            }
        }
    }

    @OnClick(R.id.iv_controller_play)
    public void changePlayStatus() {
        // 播放中
        if (mController.isPlaying()) {
            mController.pause();
            mIvPause.setImageResource(R.drawable.ic_player_pause);
            show();
//            JDPlayerView.PLAY_STATE = Constant.PLAYER.STATE_PAUSED;
//            SharePreferenceUtil.getInstance().setIsPlaying(false);
        }
        // 未播放
        else if (!mController.isPlaying()) {
            mController.start();
            mIvPause.setImageResource(R.drawable.ic_player_play);
            show();
//            JDPlayerView.PLAY_STATE = Constant.PLAYER.STATE_PLAYING;
//            SharePreferenceUtil.getInstance().setIsPlaying(true);
        }
    }

    @Override
    public void onShow() {
        mLayoutTop.setVisibility(View.VISIBLE);
        mLayoutBottom.setVisibility(View.VISIBLE);
    }

    @Override
    public void onHide() {
        mLayoutTop.setVisibility(View.GONE);
        mLayoutBottom.setVisibility(View.GONE);
    }

    @Override
    public boolean touchControlBar(MotionEvent event) {
        int[] location = new int[2];
        mLayoutTop.getLocationOnScreen(location);
        RectF topRect = new RectF(location[0], location[1], location[0] + mLayoutTop.getWidth(), location[1] + mLayoutTop.getHeight());
        boolean topContains = topRect.contains(event.getX(), event.getY());

        mLayoutBottom.getLocationOnScreen(location);
        RectF bottomRect = new RectF(location[0], location[1], location[0] + mLayoutBottom.getWidth(), location[1] + mLayoutBottom.getHeight());
        boolean bottomContains = bottomRect.contains(event.getX(), event.getY());

        return topContains || bottomContains;
    }

    /**
     *
     * 播放中,更新播放和暂停按钮
     */
    public void updatePlayState() {
            if (mController.isPlaying()) {
                mIvPause.setImageResource(R.drawable.ic_player_play);
//            SharePreferenceUtil.getInstance().setIsPlaying(true);
            } else {
                mIvPause.setImageResource(R.drawable.ic_player_pause);
            }
        if (mController.isPlaying()|| JDPlayerView.PLAY_STATE == Constant.PLAYER.ERROR)  {
            pb_controller_normal.setVisibility(GONE);
//            LogUtil.d("BLAY", "隐藏进度条 pb_controller_normal.setVisibility(GONE) "  );
        }else if (JDPlayerView.PLAY_STATE==Constant.PLAYER.IDLE || JDPlayerView.PLAY_STATE == Constant.PLAYER.SEEKING) {
            pb_controller_normal.setVisibility(VISIBLE);
//            LogUtil.d("BLAY", "展示进度条 pb_controller_normal.setVisibility(VISIBLE) "  );
        }

    }
    public void setDuration(){
//        if (JDPlayerView.PLAY_STATE == Constant.PLAYER.PREPARED) {
            duration = mController.getDuration();
            if (duration != 0) {
                mTvDuration.setText(CommonUtils.formattedTime(duration));
            }else{
                LogUtil.d("BLAY","mController.getDuration()获取到的时常为0");
            }
//        }

    }
    @OnClick(R.id.iv_controller_enlarge)
    public void enlargePlay() {
        mController.onRequestPlayMode(Constant.PLAYER.PLAY_MODE_FULL);
    }

    @OnClick(R.id.iv_controller_more)
    public void showMoreView() {
        mController.showMoreView();
    }

    /**
     * 每次切换视频，需要更新界面
     *
     * @param video 视频数据
     */
    public void updateUI(VideoBean video, int mPlayType) {
//        LogUtil.d("BLAY","--------------JDCMediaController:update");
        mTvTitle.setText(video.getName());
        switch (mPlayType) {
            case Constant.PLAYER.TYPE_VOD://点播
                mTvDuration.setVisibility(View.VISIBLE);
//                mSeekBarProgress.setEnabled(true);
                mSeekBarProgress.setVisibility(View.VISIBLE);
                break;
            case Constant.PLAYER.TYPE_LIVE://直播
                mTvDuration.setVisibility(View.INVISIBLE);
//                mSeekBarProgress.setProgress(0);
//                mSeekBarProgress.setEnabled(false);
                mSeekBarProgress.setVisibility(View.INVISIBLE);
                break;
            case Constant.PLAYER.TYPE_LOCAL://本地
                mTvDuration.setVisibility(View.VISIBLE);
//                mSeekBarProgress.setEnabled(true);
                mSeekBarProgress.setVisibility(View.VISIBLE);
                break;
            case Constant.PLAYER.TYPE_URL:
                if (mController.getDuration() > 0) {
                    //点播或者本地
                    mTvDuration.setVisibility(View.VISIBLE);
                    mSeekBarProgress.setVisibility(View.VISIBLE);
                } else {
                    LogUtil.e("BLAY", "扫码播放未获取到mController.getDuration()");
                    mTvDuration.setVisibility(View.INVISIBLE);
                    mSeekBarProgress.setVisibility(View.INVISIBLE);
                }
                break;
        }
    }
}
