package com.jdcloud.media.demo.player.cotroller;

import android.content.Context;
import android.os.Looper;
import android.os.Message;
import android.util.AttributeSet;
import android.view.GestureDetector;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.widget.RelativeLayout;
import android.widget.SeekBar;
import android.widget.TextView;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.player.bean.Stream;
import com.jdcloud.media.demo.player.widget.CustomProgressBar;
import com.jdcloud.media.demo.utils.CommonUtils;
import com.jdcloud.media.demo.utils.LogUtil;

import java.util.List;


/**
 * 播放器基础控制类
 */
public abstract class JDCMediaControllerBase extends RelativeLayout implements SeekBar.OnSeekBarChangeListener {

    private VideoGestureUtil mVideoGestureUtil;
    private boolean isShowing;

    protected LayoutInflater mLayoutInflater;
    protected BaseController mController;
    protected GestureDetector mGestureDetector;
    protected boolean mLockScreen;
    protected List<Stream> mVideoQualityList;
    protected CustomProgressBar mProgress;//滑动调节声音和音量的进度条
    protected TextView tvTimeToast;//拖动时间时候展示的toast
    protected long duration;//视频时长

    private static final int  MSG_AFTER_XSLIDE_SEEK=0;

    public JDCMediaControllerBase(Context context) {
        super(context);
        init();
    }

    public JDCMediaControllerBase(Context context, AttributeSet attrs) {
        super(context, attrs);
        init();
    }

    private android.os.Handler handler=new android.os.Handler(Looper.getMainLooper()){
        @Override
        public void handleMessage(Message msg) {
            switch (msg.what) {
                case MSG_AFTER_XSLIDE_SEEK:
                    tvTimeToast.setVisibility(GONE);
                    break;
                default:
                    break;
            }
        }
    };

    private void init() {
        mLayoutInflater = LayoutInflater.from(getContext());
        mGestureDetector = new GestureDetector(getContext(), new GestureDetector.SimpleOnGestureListener() {
            @Override
            public boolean onScroll(MotionEvent e1, MotionEvent e2, float distanceX, float distanceY) {
                if (e1 == null || e2 == null) {
                    return false;
                }
                if (mVideoGestureUtil != null && mProgress != null) {
                    mVideoGestureUtil.check(mProgress.getHeight(), e1, e2, distanceX, distanceY);
                }
                if (!isShowing) {
                    show();
                }
                return true;
            }

            @Override
            public boolean onDown(MotionEvent e) {
                if (mVideoGestureUtil != null) {
                    mVideoGestureUtil.reset(JDCMediaControllerBase.this.getWidth());
                }
                return false;
            }

        });
        mGestureDetector.setIsLongpressEnabled(false);

        mVideoGestureUtil = new VideoGestureUtil(getContext());
        mVideoGestureUtil.setVideoGestureListener(new VideoGestureUtil.VideoGestureListener() {
            @Override
            public void onBrightnessGesture(float newBrightness) {
                if (mProgress != null) {
                    mProgress.setProgress((int) (newBrightness * 100));
                    mProgress.setImageResource(R.drawable.ic_brightness);
                    mProgress.show();
                }
            }

            @Override
            public void onVolumeGesture(float volumeProgress) {
                if (mProgress != null) {
                    if (volumeProgress > 0) {
                        mProgress.setImageResource(R.drawable.ic_volume_high);
                    } else {
                        mProgress.setImageResource(R.drawable.ic_volume_mut);
                    }
                    mProgress.setProgress((int) volumeProgress);
                    mProgress.show();
                }
            }

            @Override
            public void showTimeToast(float xValue) {
//                LogUtil.e("BLAY","xValue:"+xValue);
                //显示滑动的当前时间，并且seek到相应的时间点
                if(tvTimeToast.getVisibility()==View.GONE){
                    tvTimeToast.setVisibility(View.VISIBLE);
                }
                tvTimeToast.setText(getSeekTime(xValue));
//               mController.seekTo(newCurrent);
            }

        });
//        setClickable(true);
//        setOnClickListener(new OnClickListener() {
//            @Override
//            public void onClick(View v) {
//                //点击上下黑色透明控制局部时候，为了布局上的按钮好点击，不隐藏
////                if (!mLockScreen&& !touchControlBar(event))
//                    toggle(null);
//                    LogUtil.e("BLAY","*****************onClick");
//            }
//        });
    }

    /**
     * @param xValue 滑动的距离转化成时间
     * @return  滑动后应该跳转到的时间
     */
    private String getSeekTime(float xValue){

        float weight=xValue/getWidth();//滑动的距离相对于屏幕的比例
        int seekTime = mController.getCurrentPlayTime();
        if (duration > 3600*1000) {//时长大于一小时
            seekTime += Math.round(weight * duration * 0.1);
        } else if (1800*1000 < duration && duration <= 3600*1000) {//小于一小时，大约30分钟
            seekTime += Math.round(weight * duration * 0.2);
        } else if (600*1000 < duration && duration <= 1800*1000) {//10-30分钟
            seekTime += Math.round(weight * duration * 0.34);
        } else if (240*1000 < duration && duration <= 600*1000) {//4-10分钟
            seekTime += Math.round(weight * duration * 0.5);
        } else {//小于4分钟
            seekTime += Math.round(weight * duration);
        }
        if (seekTime < 0) {
            seekTime = 0;
        } else if (seekTime > duration) {
            seekTime = (int) duration;
        }
        tvTimeToast.setTag(seekTime);
        return CommonUtils.formattedTime(seekTime);
    }

    public void setVideoQualityList(List<Stream> videoQualityList) {
        mVideoQualityList = videoQualityList;
    }

    public void setController(BaseController controller) {
        mController = controller;
    }

    @Override
    public boolean onTouchEvent(MotionEvent event) {
        int action = event.getAction();
        if(action==MotionEvent.ACTION_UP){
            if(tvTimeToast.getVisibility()==View.VISIBLE){
                handler.sendEmptyMessageDelayed(MSG_AFTER_XSLIDE_SEEK,1000);
                mController.seekTo((int)tvTimeToast.getTag());
            }
        }
        if (!mLockScreen) {
            if (mGestureDetector != null) {
                //触摸事件被自定义手势截获
                if(mGestureDetector.onTouchEvent(event)){
                    return true;
                }
            }
        }
        if (action == MotionEvent.ACTION_DOWN) {
            //点击上下黑色透明控制局部时候，为了布局上的按钮好点击，不隐藏
            if (!mLockScreen&& !touchControlBar(event))
                toggle(event);
        }
        return true;
    }


    public void toggle(MotionEvent event) {
        if (isShowing) {
            hide();
        } else {
            show();
        }
    }
    public void show() {
        isShowing = true;
        onShow();
    }

    public void hide() {
        isShowing = false;
        onHide();
    }

    @Override
    public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
        if(tvTimeToast.getVisibility()==View.VISIBLE){
            float percentage = progress==0 ? 0f:(float) (progress * 1.0 / seekBar.getMax());
//            LogUtil.e("BLAY","percentage-----"+percentage);
            if(mController!=null && mController.getDuration()!=0){
                float current=mController.getDuration()*percentage;
//                LogUtil.e("BLAY","float current-----"+current);
                int currentInt=Math.round(current);
                String showTime= CommonUtils.formattedTime(currentInt);
                tvTimeToast.setText(showTime);
            }
        }

    }

    @Override
    public void onStartTrackingTouch(SeekBar seekBar) {
        if(tvTimeToast!=null){
            tvTimeToast.setVisibility(View.VISIBLE);
        }
    }

    @Override
    public void onStopTrackingTouch(SeekBar seekBar) {
        if(tvTimeToast!=null){
            tvTimeToast.setVisibility(View.GONE);
        }
        int curProgress = seekBar.getProgress();
        int maxProgress = seekBar.getMax();
        if (curProgress >= 0 && curProgress < maxProgress) {
            float percentage = ((float) curProgress) / maxProgress;
            int position = (int) (mController.getDuration() * percentage);
            mController.seekTo(position);
        }
    }


    /**
     * 判断是否点击的上下控制布局
     * @param event
     * @return   需要子布局根据实际情况定义
     */
    public abstract boolean touchControlBar(MotionEvent event);
    public abstract void onShow();
    public abstract void onHide();



    public interface BaseController {
        int getPlayType();
        void onRequestPlayMode(int requestPlayMode);
        void onBackPressed(int playMode);
        void pause();
        void start();
        /**
         * @return 获取时长，单位：millisecond
         */
        long getDuration();

        /**
         * @return 获取当前播放的时间点，单位：millisecond
         */
        int getCurrentPlayTime();

        /**
         * @param position 单位：millisecond
         */
        void seekTo(int position);

        boolean isPlaying();

        boolean isBackgroundPlay();

        boolean isMirror();

        void onCutScreen();

        void onQualitySelected(Stream quality);

        void onSpeedChanged(float speedLevel);

        void onReplay();

        void showMoreView();

        void onGIFPress();
        void onNextVideo();
    }

}
