package com.jdcloud.media.demo.player.widget;

import android.content.Context;
import android.os.Handler;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowManager;
import android.widget.ImageView;
import android.widget.RelativeLayout;


import com.jdcloud.media.demo.MainActivity;
import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.player.GlobalPlayer;
import com.jdcloud.media.player.wrapper.JDCloudVideoView;

import java.lang.reflect.Field;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class FloatWindow extends RelativeLayout {
    private static final String TAG = "FloatWindow";

    private static final int JUST_CLICK = 5;

    private WindowManager mWindowManager;
    private WindowManager.LayoutParams mLayoutParams;
    @BindView(R.id.jdc_float)
    RelativeLayout mVideoView;
    @BindView(R.id.iv_player_float_controller_close)
    ImageView mClose;

    private Handler mHandler;

    private int statusBarHeight;

    private float xInScreen, yInScreen;

    private float xDownInScreen, yDownInScreen;

    private float xInView, yInView;


    public FloatWindow(Context context) {
        super(context);
        init(context);
    }

    public FloatWindow(Context context, AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }

    public FloatWindow(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init(context);
    }

    private void init(Context context) {
        mWindowManager = (WindowManager) context.getSystemService(Context.WINDOW_SERVICE);
        LayoutInflater.from(context).inflate(R.layout.layout_controller_float, this);
        ButterKnife.bind(this);
    }

    public void updateViewLayoutParams(WindowManager.LayoutParams params) {
        mLayoutParams = params;
    }

    public void addFloatingWindow(JDCloudVideoView videoView) {
        if(videoView.getParent()!=null){
            ((ViewGroup)videoView.getParent()).removeView(videoView);
        }
        mVideoView.addView(videoView);
        GlobalPlayer.INSTANCE.getInstance().setVisibility(View.VISIBLE);
    }

    public void removeFloatingWindow(JDCloudVideoView videoView) {
        mVideoView.removeView(videoView);
    }

    public void setHandler(Handler handler) {
        mHandler = handler;
    }

    @Override
    public boolean onTouchEvent(MotionEvent event) {
        switch (event.getAction()) {
            case MotionEvent.ACTION_UP:
                if (Math.abs(xDownInScreen - xInScreen) < JUST_CLICK && Math.abs(yDownInScreen - yInScreen) < JUST_CLICK) {
                    if (mHandler != null)
                        mHandler.obtainMessage(MainActivity.REMOVE_FLOATING_WINDOW).sendToTarget();
                }
                break;
            case MotionEvent.ACTION_DOWN:
                xInView = event.getX();
                yInView = event.getY();

                xDownInScreen = event.getRawX();
                yDownInScreen = event.getRawY() - getStatusBarHeight();

                xInScreen = xDownInScreen;
                yInScreen = yDownInScreen;
                break;
            case MotionEvent.ACTION_MOVE:
                xInScreen = event.getRawX();
                yInScreen = event.getRawY() - getStatusBarHeight();
                updateViewPosition();
                break;
        }
        return true;
    }

    private void updateViewPosition() {
        mLayoutParams.x = (int) (xInScreen - xInView);
        mLayoutParams.y = (int) (yInScreen - yInView);
        mWindowManager.updateViewLayout(this, mLayoutParams);
    }

    private int getStatusBarHeight() {
        if (statusBarHeight == 0) {
            try {
                Class<?> c = Class.forName("com.android.internal.R$dimen");
                Object o = c.newInstance();
                Field field = c.getField("status_bar_height");
                int x = (Integer) field.get(o);
                statusBarHeight = getResources().getDimensionPixelSize(x);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        return statusBarHeight;
    }

    @OnClick(R.id.iv_player_float_controller_close)
    public void closeFloatWindow() {
        if (mHandler != null)
            mHandler.obtainMessage(MainActivity.CLOSE_FLOATING_WINDOW).sendToTarget();
    }
}
