package com.jdcloud.media.demo.player.widget;

import android.content.Context;
import android.util.AttributeSet;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.RadioGroup;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.common.view.ToggleButton;
import com.jdcloud.media.demo.player.cotroller.MoreCallback;
import com.jdcloud.media.player.wrapper.view.IRenderView;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class FullMoreView extends LinearLayout implements ToggleButton.OnToggleChangedListener {
    private Context mContext;

    @BindView(R.id.tb_mirror_play)
    ToggleButton mMirrorPlayTB;
    @BindView(R.id.tb_background_play)
    ToggleButton mBackgroundPlayTB;
    @BindView(R.id.scale_mode_pattern)
    RadioGroup mScaleModeRG;

    private MoreCallback mMoreCallBack;

    public void setCallBack(MoreCallback callBack) {
        this.mMoreCallBack = callBack;
    }

    public FullMoreView(Context context) {
        super(context);
        init(context);
    }

    public FullMoreView(Context context, AttributeSet attrs) {
        super(context, attrs);
        init(context);
    }

    public FullMoreView(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        init(context);
    }

    private void init(Context context) {
        mContext = context;
        LayoutInflater.from(mContext).inflate(R.layout.layout_pop_player_full_more, this);
        ButterKnife.bind(this);
        mMirrorPlayTB.setOnToggleChanged(this);
        mBackgroundPlayTB.setOnToggleChanged(this);
        mScaleModeRG.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int checkedId) {
                switch (checkedId) {
                    case R.id.scale_mode_fill://填充
                        mMoreCallBack.scaleMode(IRenderView.SCALING_MODE_ASPECT_FIT);
                        break;
                    case R.id.scale_mode_editor://裁剪
                        mMoreCallBack.scaleMode(IRenderView.SCALING_MODE_ASPECT_FILL);
                        break;
                    case R.id.scale_mode_full://全屏
                        mMoreCallBack.scaleMode(IRenderView.SCALING_MODE_MATCH_PARENT);
                        break;
                    default:
                        break;
                }
            }
        });
    }

    @OnClick(R.id.ll_player_check_doc)
    public void checkDoc() {
        mMoreCallBack.checkDoc();
    }

    @OnClick(R.id.ll_player_audio_only)
    public void audioOnly() {
        mMoreCallBack.audioOnlyPlay();
        setVisibility(View.GONE);
    }

    @OnClick(R.id.ll_player_out_subtitle)
    public void outSubtitle() {
        mMoreCallBack.outSubtitle();
    }

    public void initBackgroundUi(boolean isBackgroundPlay) {
        if (isBackgroundPlay) {
            mBackgroundPlayTB.setToggleOn();
        } else {
            mBackgroundPlayTB.setToggleOff();
        }
    }

    public void updateMirrorUi(boolean isMirror) {
        if (isMirror) {
            mMirrorPlayTB.setToggleOn();
        } else {
            mMirrorPlayTB.setToggleOff();
        }
    }

    @Override
    public void onToggle(boolean on, int id) {

        switch (id) {
            case R.id.tb_mirror_play:
                mMoreCallBack.mirrorPlay(on);
                break;
            case R.id.tb_background_play:
                mMoreCallBack.backgroundPlay(on);
                break;
            default:
                break;
        }
    }

}
