package com.jdcloud.media.demo.player.widget;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Rect;
import android.media.MediaMetadataRetriever;
import android.media.ThumbnailUtils;
import android.os.Environment;
import android.os.Handler;
import android.os.Looper;
import android.os.Message;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Toast;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.utils.CommonUtils;
import com.jdcloud.media.demo.utils.LogUtil;
import com.jdcloud.media.demo.utils.ToastUtil;

import java.io.File;
import java.io.FileInputStream;
import java.util.Timer;
import java.util.TimerTask;

/**
 * 视频(缩略图、裁剪)进度滑动条
 */
public class VideoSeekBar extends View {

    /** 滑动的图片(左右两个) */
    private Bitmap leftBitmap;
    /** 当前View 宽度,高度 */
    private int vWidth,vHeight;
    /** 关键帧时间（最小时间） */
    private float videoFrame = 3*1000f;
    /** 视频的总长度(毫秒) */
    private int videoDuration = 10*1000;
    /** 当前播放的时间(毫秒) */
//    private int videoPlayProgress = 0;
    /** 屏幕上坐标转换时间 - X轴 横 */
    private float xTime = -1f;
    /** 是否清空内存 - 销毁资源*/
    private boolean isClearMemory = true;
    /** 是否绘制播放进度条 */
//    private boolean isDrawProgressLine = true;
    // -- 画笔 --
    /** 缩略图,播放进度画笔 */
    private Paint thumbPaint = new Paint();
//    private Paint progressPaint = new Paint();
    private Paint progressBgPaint = new Paint();
    private Paint selectedPaint = new Paint();
    // ============== 缩略图处理 ===============
    /** 缩略图数量 */
    private int thumbCount;
    /** 缩略图Bitmap */
    private Bitmap[] thumbBitmaps;
    private Context context;

    private ChangeListener listener;
    private float startTime,endTime;
    public VideoSeekBar(Context context) {
        super(context);
        this.context=context;
        init();
    }

    public VideoSeekBar(Context context, AttributeSet attrs) {
        super(context, attrs);
        this.context=context;
        init();
    }

    public VideoSeekBar(Context context, AttributeSet attrs, int defStyleAttr) {
        super(context, attrs, defStyleAttr);
        this.context=context;
        init();
    }
    public void setChangeListener(ChangeListener listener){
        this.listener=listener;
    }
    @Override
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        // --------------------
        // 绘制缩略图 - 防止进行销毁中,导致触发
        if (!isClearMemory && thumbBitmaps != null) {
            // 遍历缩略图数量
            int bitmapW=canvas.getWidth()/thumbCount;
//            canvas.get

            for (int i = 0;i < thumbCount;i++) {
                if(isClearMemory){ // 如果正在回收中,则跳出方法
                    break;
                }
                if (thumbBitmaps[i] != null) {
                    try {
                        // 绘制缩略图
//                        Rect mSrcRect = new Rect(0, 0, thumbBitmaps[i].getWidth(), thumbBitmaps[i].getHeight());
//                        Rect mDestRect = new Rect(i*bitmapW, 0, (i+1) * bitmapW, 0);

//                        canvas.drawBitmap(thumbBitmaps[i], mSrcRect,mDestRect, thumbPaint);
                        canvas.drawBitmap(thumbBitmaps[i], i * bitmapW, 0, thumbPaint);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
        }
        // 是否绘制播放进度条
//        if (isDrawProgressLine){
//            // 计算时间防止等于-1 、 防止获取高度失败
//            if (getViewWidthConvertTime() != -1f && vHeight != 0){
//                // 转换当前的X轴位置(播放进度 / 每个X轴对应的时间)
//                float convX = ((float) videoPlayProgress) / xTime;
//                // 如果大于等于View的宽度重新设置,防止线条回弹(vWidth - convX < dip 导致下次会大于vWidth,线条会回弹)
//                if(convX + dip >= vWidth){
//                    // 重置位置,直接到结尾，显示一条线
//                    convX = vWidth - (int) (dip * 1.5);
//                }
//                // 绘制一个矩形(一条线)
//                canvas.drawRect(convX, 0, convX + (dip / 2), vHeight, progressPaint);
//            }
//        }
        // --------------------
        // 判断是否裁剪模式, 并且高度不等于0,防止计算出现问题
        if ( vHeight != 0){
            // 计算右边边距值
            reckonRightSX();
            // 绘制左边滑动的X轴位置
            canvas.drawBitmap(leftBitmap, leftSX, 0, thumbPaint);
            // 绘制右边滑动的X轴位置
            canvas.drawBitmap(leftBitmap, rightSX, 0, thumbPaint);
            // === 绘制左边拖动阴影图层 ===
            if (leftSX != 0f){
                // 绘制一个矩形
                canvas.drawRect(0, 0, leftSX, vHeight, progressBgPaint);
            }
            // === 绘制右边拖动阴影图层 ===
            if (rightSX != rightMarginX){
                // 绘制一个矩形
                canvas.drawRect(rightSX + sliderIgWidth, 0, vWidth, vHeight, progressBgPaint);
            }
        }
        canvas.drawRect(leftSX,0,rightSX,20,selectedPaint);
        canvas.drawRect(leftSX,vHeight-20,rightSX,vHeight,selectedPaint);
    }

    // =====================

    // --
    /** 右边的边距（右边图片的左边距和右边屏幕的距离） */
    private float rightMarginX = 0f;
    /** 左边滑动的X轴 */
    private float leftSX = 0f;
    /** 右边滑动的X轴 */
    private float rightSX = 0f;
    /** 放缩后滑动的图片宽度 */
    private int sliderIgWidth = 0;
    // ===
    /** 上次滑动的值 */
    private float oTouchX = -1f;
    /** 旧的中间值 */
    private float lrMiddleX = -1f;
    /** 滑动的View*/
    private int touchView = -1;
    /** 滑动左边的View ，滑动右边的View，滑动左右两边中间空白部分*/
    private final int TOUCH_LEFT_VIEW = 1;
    private final int TOUCH_RIGHT_VIEW = 2;
    private final int TOUCH_MIDST_VIEW = 3;

    @Override
    public boolean onTouchEvent(MotionEvent event) {
        super.onTouchEvent(event);
        // 属于裁剪模式才进行处理
//        if(isCutMode){
            // 滑动中的X轴位置
            float xMove = event.getX();
            // --
            switch (event.getAction()) {
                case MotionEvent.ACTION_DOWN: // 按下时
                    // 这样判断是刚好在之间,为了增加触摸体验,增加多一般的边距触摸优化
                    //if (xMove >= leftSX && xMove <= (leftSX + sliderIgWidth))
                    // --
                    if (xMove >= (leftSX - sliderIgWidth / 2) && xMove <= (leftSX + ((float) sliderIgWidth) * 1.5)){
                        touchView = TOUCH_LEFT_VIEW;
                        // 计算滑动距离
                        reckonSlide(xMove);
                    } else if (xMove >= (rightSX - sliderIgWidth / 2) && xMove <= (rightSX + ((float) sliderIgWidth) * 1.5)){
                        touchView = TOUCH_RIGHT_VIEW;
                        // 计算滑动距离
                        reckonSlide(xMove);
                    } else if (xMove >= (leftSX + sliderIgWidth) && xMove <= (rightSX + sliderIgWidth)){ // 属于滑动两个View中间模块
                        touchView = TOUCH_MIDST_VIEW;
                        // 计算滑动距离
                        reckonSlide(xMove);
                    } else {  // 表示都没操作
                        lrMiddleX = oTouchX = touchView = -1;
                    }
                    break;
                case MotionEvent.ACTION_MOVE: // 滑动中
                    // 计算滑动距离
                    reckonSlide(xMove);
                    break;
                case MotionEvent.ACTION_UP: // 抬起时
                    lrMiddleX = oTouchX = touchView = -1;
//                    LogUtil.d("BLAY","startTime:getStartTime:"+startTime+"|"+getStartTime()+"，endTime:getEndTime："+endTime+","+getEndTime());
                    if(getStartTime()!=startTime || getEndTime()!=endTime){
                        if(listener!=null){
                            listener.onChange(getStartTime(),getEndTime());
                        }
                    }
                    startTime=getStartTime();
                    endTime=getEndTime();
                    break;
            }
//        }
        return true;
    }

    /** 计算右边的值 */
    private void reckonRightSX(){
        if(rightMarginX == 0f){
            rightMarginX = vWidth - sliderIgWidth;
        }
        if(rightSX == 0f){ // 默认值为0则表示为最尾端
            rightSX = rightMarginX;
        }
    }

    /**
     * 计算滑动
     * @param xMove 滑动的X轴
     */
    private void reckonSlide(float xMove){
        // 计算右边边距值
        reckonRightSX();
        // 如果都不属于滑动,则不处理
        if(!(touchView == TOUCH_LEFT_VIEW || touchView == TOUCH_RIGHT_VIEW
                || touchView == TOUCH_MIDST_VIEW)){
            return;
        }
        // 求最小宽度（最小宽度*每dp对应的时间=关键帧时间）
        float convX = videoFrame / xTime;
        // 计算间隔宽度(判断是滑动图片宽度大还是关键帧宽度大)
//        if(convX > sliderIgWidth){
//            ToastUtil.makeText(context,"最小选择时间是三秒",Toast.LENGTH_SHORT);
//        }
        float spacing = (convX > sliderIgWidth) ? convX : sliderIgWidth;
        // --
        if(touchView == 1){ // 属于滑动左边图片
            // 虚拟位置 = 滑动位置 + 间距宽度
            float vX = xMove + spacing;
            // 判断是否滑动会推动到右边
            if(vX > rightSX){
                // 如果已经给推到边缘了,则进行控制
                if (rightSX >= rightMarginX){
                    // 设置右边到边缘
                    rightSX = rightMarginX;
                    // 左边 = 右边 - 间距宽度(防止重叠)
                    leftSX = rightSX - spacing;
                } else { // 如果不在边缘,则进行推
                    leftSX = xMove;
                    rightSX = xMove + spacing;
                }
            } else { // 如果小于则表示没有触碰到
                leftSX = xMove;
                // 如果边距小于一半则滑动到底部 + 3分之1的边距
                if (xMove <= sliderIgWidth / 2 + sliderIgWidth / 3){
                    leftSX = 0f;
                }
            }
            // 最后再进行判断多一次,防止出现意外（快速滑动）
            adjustLoc(TOUCH_LEFT_VIEW, spacing);
        } else if (touchView == 2){ // 属于滑动右边图片
            // 判断是否滑动到边缘(右侧边缘)
            if(xMove >= rightMarginX){ // 滑动到边缘则直接设置边缘
                rightSX = rightMarginX;
            } else {
                // 判断是否触碰到左边 -> 滑动的距离 - 左边的位置 > 边距，表示没触碰
                if (xMove - leftSX > spacing){
                    rightSX = xMove;
                } else { // 如果触碰了
                    if (leftSX <= 0){ // 如果左边已经到了边缘
                        // 设置左边到边缘
                        leftSX = 0f;
                        // 右边 = 间距宽度
                        rightSX = spacing;
                    } else { // 左边没到边缘,则进行推
                        rightSX = xMove;
                        leftSX = rightSX - spacing;
                    }
                }
            }
            // 最后再进行判断多一次,防止出现意外（快速滑动）
            adjustLoc(TOUCH_RIGHT_VIEW, spacing);
        } else if (touchView == 3){ // 属于滑动两个View 中间空白的
            // 左右两个的间隔 = 右边减去左边（左边坐标 + 图片宽度）
            float lrSpace = rightSX - leftSX;
            if (lrMiddleX == -1f){
                // 获取中间值
                lrMiddleX = lrSpace;
            }
            // 判断滑动方向
            if (oTouchX == -1f){
                // 记录上次的滑动值
                oTouchX = xMove;
                return;
            }
            if (lrMiddleX > 0){
                // 判断左边是否已经到达最右边
                if(rightSX > rightMarginX){ // 如果已经给推到边缘了,则进行控制
                    adjustLoc(TOUCH_MIDST_VIEW, lrMiddleX); // 调整位置
                } else if (leftSX < 0){ // 如果左边的距离等于0
                    adjustLoc(TOUCH_MIDST_VIEW, lrMiddleX); // 调整位置
                } else { // 同步位移
                    // 判断滑动方向
                    if (xMove > oTouchX){ // 往右边滑动
                        if (rightSX < rightMarginX){
                            rightSX = rightSX + (xMove - oTouchX);
                            // --
                            leftSX = rightSX - lrMiddleX;
                        }
                    } else if (xMove < oTouchX){ // 往左边滑动
                        if (leftSX > 0){
                            leftSX = leftSX - (oTouchX - xMove);
                            // --
                            rightSX = leftSX + lrMiddleX;
                        }
                    }
                    // 记录上次的滑动值
                    oTouchX = xMove;
                    // 调整位置
                    adjustLoc(TOUCH_MIDST_VIEW, lrMiddleX);
                }
            }
        }
        // 进行绘制
        invalidate();
    }

    /**
     * 调整位置(防止左右超出边缘边距)
     * @param touchView 滑动的View
     * @param spacing 两个View间隔的边距
     */
    private void adjustLoc(int touchView, float spacing){
        // 判断左边是否到达边缘
        if (leftSX <= 0){
            // 设置左边到边缘
            leftSX = 0f;
            // 右边 = 间距宽度
            float tRightSX = spacing;
            // 判断当前位置是否大于边距
            if (rightSX < tRightSX){
                rightSX = tRightSX;
            }
        }
        // --
        // 判断右边是否到达边缘
        if (rightSX >= rightMarginX){
            // 设置右边到边缘
            rightSX = rightMarginX;
            // 左边 = 右边 - 间距宽度(防止重叠)
            float tLeftSX = rightSX - spacing;
            // 判断当前位置是否大于计算出来的位置
            if (leftSX > tLeftSX){
                leftSX = tLeftSX;
            }
        }
    }

    // ===========================================

    /**
     * 初始化操作
     */
    private void init(){
//        setTimer(true);
        // 防止不进行绘画 触发onDraw
        setWillNotDraw(false);
        // 获取左右两个滑动的图片
//        leftBitmap = BitmapFactory.decodeResource(getContext().getResources(), R.drawable.ic_red_point);
        leftBitmap = BitmapFactory.decodeResource(getContext().getResources(), R.drawable.seekbar_l);
        // 先保存滑动图片宽度
        sliderIgWidth = leftBitmap.getWidth();
//        LogUtil.d("BLAY","init:sliderIgWidth图片宽度---------"+sliderIgWidth);
        // 1 dip 对应的px
//        dip = ScreenUtils.dipConvertPx(getContext(), 1.0f);
//        final float scale = getContext().getResources().getDisplayMetrics().density;
//        dip=(int)(1.0f * scale + 0.5f);
        // 初始化画笔
        initPaint();
        startTime=0f;
        endTime=10000f;
    }

    /**
     * 初始化画笔
     */
    private void initPaint(){
        // 初始化画笔
        thumbPaint = new Paint(Paint.ANTI_ALIAS_FLAG); // 缩略图
//        progressPaint = new Paint(Paint.ANTI_ALIAS_FLAG); // 播放进度 白色竖直线条
        progressBgPaint = new Paint(Paint.ANTI_ALIAS_FLAG); // 播放进度背景,半透明(画布遮挡层)
        // 画笔颜色
        selectedPaint.setColor(Color.rgb(255, 255, 255)); // 字体颜色 - 白色
        progressBgPaint.setColor(Color.rgb(0, 0, 0)); // 背景进度颜色(画布遮挡层)
        // 设置透明度
        progressBgPaint.setAlpha(200); // 画布遮挡层
        // 设置画笔大小
//        progressPaint.setStrokeWidth(dip * 2); // 线条
        // 设置画笔样式
//        progressPaint.setStyle(Paint.Style.STROKE); // 设置粗线 - 线条
    }

    // ============== 内部计算方法  ==============

    /**
     * 获取View的宽度，转换对应的坐标值 = 时间
     * @return
     */
    private float getViewWidthConvertTime(){
        if(xTime == -1f){
            if( 0<vWidth&& videoDuration != 0){
                // 视频总进度 / 宽度 = 每个坐标占用多少毫秒
                xTime = videoDuration*1f/vWidth;
                LogUtil.d("BLAY","****************************xTime:"+xTime);
            }
        }
        return xTime;
    }

    /**
     * 获取滑动图片
     * @return
     */
    private Bitmap getSliderBitmap(){
        // 防止高度为0
        if(vHeight != 0){
            // 获取高度进行计算
            int bHeight = leftBitmap.getHeight();
            // 判断是否需要缩放,高度不一直则要求缩放
            if (bHeight != vHeight){
                // 获取图片宽度
//                int bWidth = 10;
                int bWidth = leftBitmap.getWidth();
                LogUtil.d("BLAY","vHeight:bHeight:bWidth---------"+vHeight+","+bHeight+","+bWidth);
                // 计算宽度比例
//                bWidth=Math.round((vHeight /(bHeight*1f) * bWidth));
                bWidth = 40;
                // 保存缩放比例后的宽度
                sliderIgWidth = bWidth;
                LogUtil.d("BLAY","缩放后图片宽度sliderIgWidth---------"+sliderIgWidth);
                // 进行比例缩放图片
                leftBitmap = Bitmap.createScaledBitmap(leftBitmap, bWidth, vHeight, true);
//                rightBitmap = Bitmap.createScaledBitmap(rightBitmap, bWidth, vHeight, true);
            }
        }
        return leftBitmap;
    }

    // ============== 内部处理方法  ==============

    /** 回收缩略图内存 */
    private void clearThumbs(){
        vWidth=0;
        rightMarginX=0;
        leftSX=0;
        rightSX=0;
        // 销毁资源中
        isClearMemory = true;
        // --
        if(thumbBitmaps != null){
            for(int i = 0, c = thumbBitmaps.length;i < c;i++){
                Bitmap bitmap = thumbBitmaps[i];
                if(bitmap != null){
                    if(bitmap != null && !bitmap.isRecycled()){
                        try {
                            bitmap.recycle();
                        } catch (Exception e) {
                        }
                    }
                    bitmap = null;
                }
            }
        }
    }

    /** 创建缩略图 */
    public void buildThumbs(){
        // 先回收旧的内容
        clearThumbs();
        // 重新绘制进行刷新
        postInvalidate();
        // 判断路径是否为null
//        if(!TextUtils.isEmpty(videoUri)){
            // 开启后台线程，生成缩略图
            new Thread(btRunn).start();
//        }
    }

    /** 生成缩略图（来自本地视频） */
    private void buildThumbsToLocal(){
            // 防止两个都为默认值
            while(vWidth <= 0 || vHeight <= 0){
                vWidth = getWidth();
                vHeight = getHeight();
            }
            // 进行计算滑动的边距
            getSliderBitmap();
            // 计算右边边距值
            reckonRightSX();
            // 获取View的宽度，转换对应的坐标值 = 时间
            getViewWidthConvertTime();
    }

    /** buildThumbs Runnable 创建缩略图线程 */
    private Runnable btRunn = new Runnable() {
        @Override
        public void run() {
            isClearMemory = false;
            buildThumbsToLocal();
            // 获取文件路径
//            File file=new File(context.getExternalFilesDirs(Environment.DIRECTORY_DOWNLOADS)[0].getPath()+"/gif");
            File file = new File(CommonUtils.getGifTemp(context));
            // 判断是否本地文件
            if(file.exists()){
                // 初始化缩略图容器
                File[] files = file.listFiles();
                if(files.length<=0){
                    return;
                }
                thumbCount=files.length;
                thumbBitmaps = new Bitmap[files.length];
                // 遍历生成缩略图
                try {
//                    for (int i = 0;i < thumbCount;i++) {
                    int i=0;
                   for(File f:files){
                       if(f.isFile()){
                           FileInputStream fis = new FileInputStream(f.getAbsolutePath());
//                    FileInputStream fis = new FileInputStream(Environment.getExternalStorageDirectory()+"jdcplayer/git"+f.getName());
                           Bitmap bitmap  = BitmapFactory.decodeStream(fis);
                           // 保存缩略图
                           thumbBitmaps[i] =bitmap;
                           // 刷新界面
                           postInvalidate();
                           i++;
                       }
                    }
                }catch (Exception e){
                    e.printStackTrace();
                }

            }
        }
    };

    /**
     * 设置视频的总长度(内部处理 - MediaMetadataRetriever 获取) - 毫秒
     * @param videoDuration
     */
    private void setVideoDuration(int videoDuration){
        this.videoDuration = videoDuration;
    }


    // ============== 内部控制代码 ===============
    /** 专门刷新View */
    private Handler vhandler = new Handler(Looper.getMainLooper()){
        @Override
        public void handleMessage(Message msg) {
            switch(msg.what){
                case 0: // 正常进行绘制触发
                    postInvalidate();
                    break;
                case 1: // 满一秒进行触发
                    displayTime = displayTime + 1000; // 累积时间
//              if(rtCallBack != null){
//                  rtCallBack.preSecond(displayTime);
//              }
                    break;
            }
        }
    };

    /** 设备连接定时器 */
    private Timer refTimer;
    /** 设备连接定时器任务栈 */
    private TimerTask refTask;
    /** 整秒统计 */
    private int iTime = 0;
    /** 刷新时间（毫秒） */
    private int refTime = 500; // 250
    /** 刷新频率 1000 / 刷新时间 */
    private int refRate = 1000 / refTime;
    /** 对外获取时间 */
    private long displayTime = 0l;

    /**
     * 设置定时器，刷新View
     * @param isOpen 是否打开
     */
//    private void setTimer(boolean isOpen) {
//        if (isOpen) {
//            try {
//                if (refTimer != null) {
//                    refTimer.cancel();
//                    refTimer = null;
//                }
//                if (refTask != null) {
//                    refTask.cancel();
//                    refTask = null;
//                }
//            } catch (Exception e) {
//                e.printStackTrace();
//            }
//            // 开启定时器
//            refTimer = new Timer(); // 每次重新new 防止被取消
//            // 重新生成定时器 防止出现TimerTask is scheduled already 所以同一个定时器任务只能被放置一次
//            refTask = new TimerTask() {
//                @Override
//                public void run() {
//                    // 累加播放时间
//                    videoPlayProgress += refTime;
//                    // 如果大于总时间则进行重置
//                    if(videoDuration != 0 && videoPlayProgress > videoDuration){
//                        videoPlayProgress = videoDuration;
//                        // 进行通知最后一次
//                        vhandler.sendEmptyMessage(0);
//                        // 并且关闭定时器
//                        setTimer(false);
//                        return;
//                    }
//                    // --
//                    vhandler.sendEmptyMessage(0);
//                    ++ iTime;
//                    if(iTime >= refRate){
//                        vhandler.sendEmptyMessage(1);
//                        iTime = 0; // 满1秒
//                    }
//                }
//            };
//            // xx秒后执行，每隔xx秒再执行一次
//            refTimer.schedule(refTask, 0, refTime); // 开启定时器
//        } else {
//            try {
//                if (refTimer != null) {
//                    refTimer.cancel();
//                    refTimer = null;
//                }
//                if (refTask != null) {
//                    refTask.cancel();
//                    refTask = null;
//                }
//            } catch (Exception e) {
//                e.printStackTrace();
//            }
//            vhandler.sendEmptyMessage(0);
//        }
//    }

    // ============== 对外公开方法 ===============

    /**
     * 销毁操作方法
     */
    public void destroy(){
        clearThumbs();
    }

    /**
     * 获取开始时间(左边X轴转换时间) - 毫秒
     * @return
     */
    public float getStartTime(){
        if(getViewWidthConvertTime() != -1){
            LogUtil.d("BLAY","leftSX:"+leftSX+",getStartTime:"+leftSX * xTime);
            return leftSX * xTime;
        }
        return -1f;
    }

    /**
     * 获取结束时间(右边X轴转换时间) - 毫秒
     * @return
     */
    public float getEndTime(){
        if(getViewWidthConvertTime() != -1){
            LogUtil.d("BLAY","vWidth:"+vWidth+",videoDuration："+videoDuration+"；rightSX:"+rightSX+"，xTime："+xTime);
            LogUtil.d("BLAY","sliderIgWidth:"+sliderIgWidth+",getEndTime:"+(rightSX+sliderIgWidth)* xTime);
//            LogUtil.d("BLAY","thumbCount："+thumbCount);
            return (rightSX+sliderIgWidth)* xTime;
        }
        return -1f;
    }

//    /**
//     * 设置当前播放进度
//     * @param curTime 当前的时间(毫秒)
//     */
//    public void setProgress(int curTime){
//        this.videoPlayProgress = curTime;
//    }
public interface ChangeListener{
        public void onChange(float startTime,float endTime);
    }

}
