package com.jdcloud.media.demo.push.audio;

import android.content.Context;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.push.AudioData;

import java.util.List;

public class AudioAdapter extends RecyclerView.Adapter<AudioAdapter.AudioHolder> {

    private Context mContext;
    private OnItemClickListener mListener;
    private List<AudioData> mDataList;
    private int mSelectedIndex;

    public void setSelectedIndex(int pos) {
        this.mSelectedIndex = pos;
        notifyDataSetChanged();
    }

    public AudioAdapter(Context context, List<AudioData> dataList) {
        this.mContext = context;
        this.mDataList = dataList;
    }

    public void setClickListener(OnItemClickListener listener) {
        this.mListener = listener;
    }

    @Override
    public AudioHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View v = LayoutInflater.from(parent.getContext()).inflate(R.layout.layout_audio_call_item, parent, false);
        AudioHolder ah = new AudioHolder(v);
        ah.itemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (mListener != null) {
                    mListener.onItemClick(v);
                }
            }
        });
        return ah;
    }

    @Override
    public void onBindViewHolder(AudioHolder holder, int position) {
        AudioData data = null;
        if (mDataList != null) {
            data = mDataList.get(position);
        }

        if (data != null) {
            holder.mTitleTV.setText(data.getTitle());
            holder.mDurationTV.setText(data.getDuration());
            if (mSelectedIndex == position) {
                holder.mAudioCallIV.setImageResource(R.drawable.ic_radio_choose);
                holder.mHolderView.setBackgroundResource(R.color.audio_call_item_normal_color);
            } else {
                holder.mAudioCallIV.setImageResource(R.drawable.ic_radio_unchoose);
                holder.mHolderView.setBackgroundResource(R.color.common_bg_color);

            }
        }
    }

    @Override
    public int getItemCount() {
        if (mDataList != null) {
            return mDataList.size();
        }
        return 0;
    }

    class AudioHolder extends RecyclerView.ViewHolder {
        private TextView mTitleTV;
        private TextView mDurationTV;
        private ImageView mAudioCallIV;
        private View mHolderView;

        public AudioHolder(View itemView) {
            super(itemView);
            mHolderView = itemView;
            mTitleTV = itemView.findViewById(R.id.tv_audio_call_name);
            mDurationTV = itemView.findViewById(R.id.tv_audio_call_duration);
            mAudioCallIV = itemView.findViewById(R.id.iv_audio_call);
        }
    }

    public interface OnItemClickListener {
        void onItemClick(View view);
    }
}
