package com.jdcloud.media.demo.push.ui;

import android.content.Intent;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.view.View;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.base.BaseActivity;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.push.AudioData;
import com.jdcloud.media.demo.push.audio.AudioAdapter;
import com.jdcloud.media.demo.utils.ActivityUtil;

import java.util.ArrayList;
import java.util.List;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class AudioCallListActivity extends BaseActivity {

    @BindView(R.id.rv_audio_call_list)
    RecyclerView mAudioListRV;
    @BindView(R.id.action_bar_back)
    RelativeLayout mActionBarBack;
    @BindView(R.id.action_bar_setting)
    RelativeLayout mActionBarSetting;
    @BindView(R.id.action_bar_title)
    TextView mTitle;

    private int mDefaultIndex;

    private List<AudioData> mDataList = new ArrayList();
    private AudioData mData;
    private AudioAdapter mAdapter;


    @Override
    public void initView() {
        setContentView(R.layout.activity_audio_call);
        ButterKnife.bind(this);
        ActivityUtil.INSTANCE.addActivity(this);
    }

    @Override
    public void setActionBar() {
        mActionBarBack.setVisibility(View.VISIBLE);
        mActionBarSetting.setVisibility(View.GONE);
        mTitle.setText(R.string.voice_call);

    }

    @Override
    public void initData() {
        for (int i = 0; i < 4; i++) {
            switch (i) {
                case 0:
                    mData = new AudioData("无", "");
                    break;
                case 1:
                    mData = new AudioData("jdc_audio_" + i, "03:41");
                    break;
                case 2:
                    mData = new AudioData("jdc_audio_" + i, "01:52");
                    break;
                case 3:
                    mData = new AudioData("jdc_audio_" + i, "04:19");
                    break;
                default:
                    break;
            }
            mDataList.add(mData);
        }
    }

    @OnClick(R.id.action_bar_back)
    public void handleBack() {
        onBackPressed();
    }

    @Override
    public void initListener() {
        mAdapter = new AudioAdapter(this, mDataList);
        mDefaultIndex = getIntent().getIntExtra(Constant.AUDIO_CALL_INDEX, 0);
        mAdapter.setSelectedIndex(mDefaultIndex);
        mAudioListRV.setLayoutManager(new LinearLayoutManager(this, LinearLayoutManager.VERTICAL, false));
        mAudioListRV.setAdapter(mAdapter);
        mAdapter.setClickListener(new AudioAdapter.OnItemClickListener() {
            @Override
            public void onItemClick(View view) {
                int position = mAudioListRV.getChildAdapterPosition(view);
                TextView titleView = view.findViewById(R.id.tv_audio_call_name);
                String audioPath;
                if (titleView.getText().equals("无")) {
                    audioPath = titleView.getText().toString();
                } else {
                    audioPath = "assets://audio/" + titleView.getText().toString() + ".mp3";
                }
                mAdapter.setSelectedIndex(position);
                Intent intent = new Intent();
                intent.putExtra(Constant.AUDIO_CALL_PATH, audioPath);
                intent.putExtra(Constant.AUDIO_CALL_INDEX, position);
                setResult(RESULT_OK, intent);
                finish();
            }
        });
    }
}
