package com.jdcloud.media.demo.push.ui;

import android.app.Application;
import android.content.Intent;
import android.graphics.PixelFormat;
import android.net.Uri;
import android.opengl.GLSurfaceView;
import android.os.Build;
import android.provider.Settings;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.Surface;
import android.view.View;
import android.view.WindowManager;
import android.widget.ImageView;
import android.widget.RelativeLayout;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.base.BaseActivity;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.common.view.FloatView;
import com.jdcloud.media.demo.push.PushUtil;

public class PushBaseActivity extends BaseActivity {
    private ImageView mFloatClose;
    private boolean isFloatPush;
    private FloatView mFloatLayout;
    private WindowManager.LayoutParams mWmParams;
    private WindowManager mWindowManager;
    private GLSurfaceView mCameraView;
    private final static int PERMISSION_REQUEST_CODE = 100;
    private int mFloatWidth, mFloatHeight;

    @Override
    public void initView() {
    }

    @Override
    protected void onNewIntent(Intent intent) {
        setIntent(intent);
        initData();
        super.onNewIntent(intent);
    }

    @Override
    public void initData() {
        if (getIntent() != null) {
            isFloatPush = getIntent().getBooleanExtra(Constant.IS_FLOAT_PUSH, false);
        }
        if (isFloatPush) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M && !Settings.canDrawOverlays(this)) {
                Intent intent = new Intent(Settings.ACTION_MANAGE_OVERLAY_PERMISSION,
                        Uri.parse("package:" + getPackageName()));
                startActivityForResult(intent, PERMISSION_REQUEST_CODE);
            } else {
                if (!PushUtil.INSTANCE.isFloatViewShow()) {
                    addFloatView();
                }
            }
        }

    }

    private void addFloatView() {
        if (mWindowManager == null) {
            mWmParams = new WindowManager.LayoutParams();
            mWindowManager = (WindowManager) getApplication().
                    getSystemService(Application.WINDOW_SERVICE);

            if (Build.VERSION.SDK_INT >= 26) {
                mWmParams.type = WindowManager.LayoutParams.TYPE_APPLICATION_OVERLAY;
            } else
                mWmParams.type = WindowManager.LayoutParams.TYPE_TOAST;
            mWmParams.format = PixelFormat.RGBA_8888;
            mWmParams.flags = WindowManager.LayoutParams.FLAG_NOT_FOCUSABLE;
            mWmParams.flags |= WindowManager.LayoutParams.FLAG_HARDWARE_ACCELERATED;
            mWmParams.flags |= WindowManager.LayoutParams.FLAG_WATCH_OUTSIDE_TOUCH;
            mWmParams.flags |= WindowManager.LayoutParams.FLAG_LAYOUT_NO_LIMITS;
            mWmParams.gravity = Gravity.CENTER;
            mWmParams.x = 0;
            mWmParams.y = 0;
            int screenWidth = mWindowManager.getDefaultDisplay().getWidth();
            int screenHeight = mWindowManager.getDefaultDisplay().getHeight();
            boolean isLandscape = (getDisplayRotation() % 180) != 0;
            if ((isLandscape && screenWidth < screenHeight) ||
                    (!isLandscape) && screenWidth > screenHeight) {
                screenWidth = mWindowManager.getDefaultDisplay().getHeight();
                screenHeight = mWindowManager.getDefaultDisplay().getWidth();
            }
            if (screenWidth < screenHeight) {
                mFloatWidth = align(screenWidth / 2, 8);
                mFloatHeight = align(screenHeight / 2, 8);
            } else {
                mFloatWidth = align(screenWidth / 2, 8);
                mFloatHeight = align(screenHeight / 2, 8);
            }
            mWmParams.width = WindowManager.LayoutParams.WRAP_CONTENT;
            mWmParams.height = WindowManager.LayoutParams.WRAP_CONTENT;

            LayoutInflater inflater = LayoutInflater.from(getApplication());
            mFloatLayout = (FloatView) inflater.inflate(R.layout.layout_float_preview, null);
            mFloatClose = new ImageView(this);
            mFloatClose.setImageResource(R.drawable.ic_close);
            mFloatClose.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    PushUtil.INSTANCE.destroyStreamer();
                    if (mWindowManager != null) {
                        mWindowManager.removeViewImmediate(mFloatLayout);
                        mFloatLayout.removeAllViews();
                    }
                }
            });
            mFloatLayout.setWmParams(mWmParams);
        }

        if (mWindowManager != null) {
            mCameraView = new GLSurfaceView(this);
            RelativeLayout.LayoutParams previewLayoutParams =
                    new RelativeLayout.LayoutParams(mFloatWidth, mFloatHeight);
            mFloatLayout.addView(mCameraView, previewLayoutParams);
            if (PushUtil.INSTANCE.getStreamer() != null) {
                PushUtil.INSTANCE.getStreamer().setDisplayPreview(mCameraView);
                RelativeLayout.LayoutParams closeParams =
                        new RelativeLayout.LayoutParams(getResources().getDimensionPixelSize(R.dimen.common_size), getResources().getDimensionPixelSize(R.dimen.common_size));
                closeParams.setMargins(getResources().getDimensionPixelSize(R.dimen.common_rl_padding), getResources().getDimensionPixelSize(R.dimen.common_rl_padding), 0, 0);
                mFloatLayout.addView(mFloatClose, closeParams);
                mWindowManager.addView(mFloatLayout, mWmParams);
                PushUtil.INSTANCE.setFloatViewShow(true);
            }
        }
    }

    private int getDisplayRotation() {
        int rotation = getWindowManager().getDefaultDisplay().getRotation();
        switch (rotation) {
            case Surface.ROTATION_0:
                return 0;
            case Surface.ROTATION_90:
                return 90;
            case Surface.ROTATION_180:
                return 180;
            case Surface.ROTATION_270:
                return 270;
        }
        return 0;
    }

    private int align(int val, int align) {
        return (val + align - 1) / align * align;
    }

    @Override
    public void initListener() {

    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == PERMISSION_REQUEST_CODE) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                if (!Settings.canDrawOverlays(this)) {
                } else {
                    addFloatView();
                }
            }
        }
    }
}
