package com.jdcloud.media.demo.push.ui;

import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.text.TextUtils;
import android.view.View;
import android.view.WindowManager;
import android.widget.EditText;
import android.widget.RadioGroup;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.common.view.ToggleButton;
import com.jdcloud.media.demo.push.PushUtil;
import com.jdcloud.media.demo.push.config.BaseConfig;
import com.jdcloud.media.demo.push.config.SeniorConfig;
import com.jdcloud.media.demo.utils.ActivityUtil;
import com.jdcloud.media.demo.utils.LogUtil;
import com.jdcloud.media.live.base.AVConst;
import com.jdcloud.media.live.capture.CameraCapture;
import com.jdcloud.media.live.config.BaseConstants;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class PushSeniorSettingActivity extends PushBaseActivity implements ToggleButton.OnToggleChangedListener {

    private static final String TAG = PushSeniorSettingActivity.class.getSimpleName();

    @BindView(R.id.action_bar_back)
    RelativeLayout mActionBarBack;
    @BindView(R.id.action_bar_title)
    TextView mTitle;
    @BindView(R.id.live_senior_push_resolution_pattern)
    RadioGroup mPushResolution;
    @BindView(R.id.live_senior_capture_resolution_pattern)
    RadioGroup mCaptureResolution;
    @BindView(R.id.live_senior_preview_resolution_pattern)
    RadioGroup mPreviewResolution;
    @BindView(R.id.live_bitrate_pattern)
    RadioGroup mVideoBitrate;
    @BindView(R.id.live_bitrate_regulate)
    RadioGroup mBitrateRegulate;
    @BindView(R.id.et_frame_rate)
    EditText mFrameRate;
    @BindView(R.id.live_key_frame)
    RadioGroup mKeyFrame;
    @BindView(R.id.live_senior_encoder_pattern)
    RadioGroup mVideoEncoderPattern;
    @BindView(R.id.live_sampling_rate_pattern)
    RadioGroup mSamplingRate;
    @BindView(R.id.live_audio_bit_rate_pattern)
    RadioGroup mAudioBitrate;
    @BindView(R.id.live_audio_encoder_pattern)
    RadioGroup mAudioEncoderPattern;
    @BindView(R.id.live_voice_channel)
    RadioGroup mVoiceChannel;
    @BindView(R.id.live_device_pattern)
    RadioGroup mDevicePattern;
    @BindView(R.id.live_camera_pattern)
    RadioGroup mCameraPattern;
    @BindView(R.id.tb_background_push)
    ToggleButton mBackgroundPush;
    @BindView(R.id.et_reconnect_time)
    EditText mReconnectTime;
    @BindView(R.id.et_reconnect_count)
    EditText mReconnectCount;
    @BindView(R.id.tb_live_pip)
    ToggleButton mPIP;

    private BaseConfig mBaseConfig;
    private SeniorConfig mSeniorConfig;


    @Override
    public void initView() {
        setContentView(R.layout.activity_live_senior_setting);
        ButterKnife.bind(this);
        ActivityUtil.INSTANCE.addActivity(this);
        getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_ADJUST_RESIZE | WindowManager.LayoutParams.SOFT_INPUT_STATE_HIDDEN);
    }

    @Override
    public void initData() {
        super.initData();
        mBaseConfig = (BaseConfig) getIntent().getSerializableExtra(Constant.PUSH_BASE_CONFIG);
        if (mBaseConfig != null) {
            initConfig();
        }
    }

    private void initConfig() {
        mSeniorConfig = new SeniorConfig();
        mSeniorConfig.mUrl = mBaseConfig.mUrl;
        mSeniorConfig.mEncodeMethod = mBaseConfig.mEncodeMethod;
        mSeniorConfig.mResolution = mBaseConfig.mResolution;
        mSeniorConfig.mPerformance = mBaseConfig.mPerformance;
        mSeniorConfig.mCaptureFrom = mBaseConfig.mCaptureFrom;
        mSeniorConfig.mSense = mBaseConfig.mSense;
        initSeniorConfig();
    }

    @Override
    public void setActionBar() {
        mTitle.setText(R.string.senior_setting);
        mActionBarBack.setVisibility(View.VISIBLE);
    }

    private void initSeniorConfig() {
        //push resolution
        switchPushResolution(mPushResolution.getCheckedRadioButtonId());
        //capture resolution
        switchCaptureResolution(mCaptureResolution.getCheckedRadioButtonId());
        //preview resolution
        switchPreviewResolution(mPreviewResolution.getCheckedRadioButtonId());
        //video bitrate
        switchVideoBitRate(mVideoBitrate.getCheckedRadioButtonId());
        //bitrate Regulate
        switchBitrateRegulate(mBitrateRegulate.getCheckedRadioButtonId());
        //frame rate
        mSeniorConfig.mFrameRate = dealWithEditTextInt(mFrameRate);
        //key frame
        switchKeyFrame(mKeyFrame.getCheckedRadioButtonId());
        //video encoder pattern
        switchVideoEncodePattern(mVideoEncoderPattern.getCheckedRadioButtonId());
        //sampling rate
        switchSampleRate(mSamplingRate.getCheckedRadioButtonId());
        //audio bitrate
        switchAudioBitRate(mAudioBitrate.getCheckedRadioButtonId());
        //audio encoder pattern
        switchAudioEncodePattern(mAudioEncoderPattern.getCheckedRadioButtonId());
        //voice channel
        switchVoiceChannel(mVoiceChannel.getCheckedRadioButtonId());
        // Device Pattern
        switchDevicePattern(mDevicePattern.getCheckedRadioButtonId());
        //camera pattern
        switchCameraPattern(mCameraPattern.getCheckedRadioButtonId());
        // background push
        mSeniorConfig.mBackgroundPush = mBackgroundPush.getToggleStatus();
        //pip mode
        mSeniorConfig.mPIPMode = mPIP.getToggleStatus();
        //reconnect time
        mSeniorConfig.mReconnectTime = dealWithEditText(mReconnectTime);
        //reconnect count
        mSeniorConfig.mReconnectCount = dealWithEditText(mReconnectCount);
    }
    private int dealWithEditText(EditText editText) {
        int result = 0;

        if (TextUtils.isEmpty(editText.getText())) {
            return result;
        } else {
            try {
                result = Integer.parseInt(editText.getText().toString());
            } catch (Exception e) {
                e.printStackTrace();
            }
            return result;
        }
    }

    private float dealWithEditTextInt(EditText editText) {
        float result = 0;
        if (TextUtils.isEmpty(editText.getText())) {
            return result;
        } else {
            try {
                result = Integer.parseInt(editText.getText().toString());
            } catch (Exception e) {
                e.printStackTrace();
            }
            if (result < 10) {
                result = 10;
                editText.setText("10");
            } else if (result > 60) {
                result = 60;
                editText.setText("60");
            }
            return result;
        }
    }

    @Override
    protected void onNewIntent(Intent intent) {
        setIntent(intent);
        if (mBaseConfig != null) {
            initConfig();
        }

        super.onNewIntent(intent);
    }

    @Override
    public void initListener() {
        mBackgroundPush.setOnToggleChanged(this);
        mPIP.setOnToggleChanged(this);
        mPushResolution.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchPushResolution(i);
            }
        });
        mCaptureResolution.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchCaptureResolution(i);
            }
        });
        mPreviewResolution.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchPreviewResolution(i);
            }
        });
        mVideoBitrate.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchVideoBitRate(i);
            }
        });
        mBitrateRegulate.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchBitrateRegulate(i);
            }
        });
        mKeyFrame.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchKeyFrame(i);
            }
        });
        mVideoEncoderPattern.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchVideoEncodePattern(i);
            }
        });
        mSamplingRate.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchSampleRate(i);
            }
        });
        mAudioEncoderPattern.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchAudioEncodePattern(i);
            }
        });

        mVoiceChannel.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchVoiceChannel(i);
            }
        });

        mDevicePattern.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchDevicePattern(i);
            }
        });
        mCameraPattern.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchCameraPattern(i);
            }
        });
        mAudioBitrate.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup group, int i) {
                switchCameraPattern(i);
            }
        });
    }

    @OnClick(R.id.action_bar_back)
    public void goBack() {
        onBackPressed();
    }

    @OnClick(R.id.senior_push)
    public void goPush() {
        if (PushUtil.INSTANCE.isPushIng()) {
            Toast.makeText(this, "请先关闭悬浮窗！", Toast.LENGTH_SHORT).show();
        } else {
            Intent i = new Intent(this, PushActivity.class);
            i.putExtra(Constant.PUSH_SENIOR_CONFIG, mSeniorConfig);
            startActivity(i);
        }
    }

    private void switchPushResolution(int id) {
        switch (id) {
            case R.id.push_resolution_360p:
                mSeniorConfig.mPushResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
            case R.id.push_resolution_540p:
                mSeniorConfig.mPushResolution = BaseConstants.VIDEO_RESOLUTION_540P;
                break;
            case R.id.push_resolution_720p:
                mSeniorConfig.mPushResolution = BaseConstants.VIDEO_RESOLUTION_720P;
                break;
            case R.id.push_resolution_1080p:
                mSeniorConfig.mPushResolution = BaseConstants.VIDEO_RESOLUTION_1080P;
                break;
            default:
                mSeniorConfig.mPushResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
        }
    }

    private void switchCaptureResolution(int id) {
        switch (id) {
            case R.id.capture_resolution_360p:
                mSeniorConfig.mCaptureResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
            case R.id.capture_resolution_540p:
                mSeniorConfig.mCaptureResolution = BaseConstants.VIDEO_RESOLUTION_540P;
                break;
            case R.id.capture_resolution_720p:
                mSeniorConfig.mCaptureResolution = BaseConstants.VIDEO_RESOLUTION_720P;
                break;
            case R.id.capture_resolution_1080p:
                mSeniorConfig.mCaptureResolution = BaseConstants.VIDEO_RESOLUTION_1080P;
                break;
            default:
                mSeniorConfig.mCaptureResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
        }
    }

    private void switchPreviewResolution(int id) {
        switch (id) {
            case R.id.preview_resolution_360p:
                mSeniorConfig.mPreviewResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
            case R.id.preview_resolution_540p:
                mSeniorConfig.mPreviewResolution = BaseConstants.VIDEO_RESOLUTION_540P;
                break;
            case R.id.preview_resolution_720p:
                mSeniorConfig.mPreviewResolution = BaseConstants.VIDEO_RESOLUTION_720P;
                break;
            case R.id.preview_resolution_1080p:
                mSeniorConfig.mPreviewResolution = BaseConstants.VIDEO_RESOLUTION_1080P;
                break;
            default:
                mSeniorConfig.mPreviewResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
        }
    }

    private void switchVideoBitRate(int id) {
        switch (id) {
            case R.id.bitrate_400:
                mSeniorConfig.mBitRate = 400;
                break;
            case R.id.bitrate_600:
                mSeniorConfig.mBitRate = 600;
                break;
            case R.id.bitrate_800:
                mSeniorConfig.mBitRate = 800;
                break;
            case R.id.bitrate_1000:
                mSeniorConfig.mBitRate = 1000;
                break;
            default:
                mSeniorConfig.mBitRate = 400;
                break;
        }
    }

    private void switchBitrateRegulate(int id) {
        switch (id) {
            case R.id.bitrate_regulate_constant:
                mSeniorConfig.mRegulateBitrate = 1;
                break;
            case R.id.bitrate_regulate_dynamic:
                mSeniorConfig.mRegulateBitrate = 0;
                break;
            default:
                mSeniorConfig.mRegulateBitrate = 1;
                break;
        }
    }

    private void switchKeyFrame(int id) {
        switch (id) {
            case R.id.key_frame_1s:
                mSeniorConfig.mKeyFrame = 1;
                break;
            case R.id.key_frame_2s:
                mSeniorConfig.mKeyFrame = 2;
                break;
            case R.id.key_frame_3s:
                mSeniorConfig.mKeyFrame = 3;
                break;
            case R.id.key_frame_4s:
                mSeniorConfig.mKeyFrame = 4;
                break;
            case R.id.key_frame_5s:
                mSeniorConfig.mKeyFrame = 5;
                break;
            default:
                mSeniorConfig.mKeyFrame = 5;
                break;
        }
    }

    private void switchVideoEncodePattern(int id) {
        switch (id) {
            case R.id.senior_encoder_software:
                mSeniorConfig.mVideoEncodedFunc = BaseConstants.ENCODE_METHOD_SOFTWARE;
                break;
            case R.id.senior_encoder_self_adapt:
                mSeniorConfig.mVideoEncodedFunc = BaseConstants.ENCODE_METHOD_HARDWARE;
                break;
            case R.id.senior_encoder_hardware:
                mSeniorConfig.mVideoEncodedFunc = BaseConstants.ENCODE_METHOD_HARDWARE;
                break;
            default:
                mSeniorConfig.mVideoEncodedFunc = BaseConstants.ENCODE_METHOD_HARDWARE;
                break;
        }
    }

    private void switchSampleRate(int id) {
        switch (id) {
            case R.id.sampling_rate_32:
                mSeniorConfig.mAudioBitrate = 32;
                break;
            case R.id.sampling_rate_44:
                mSeniorConfig.mAudioBitrate = 44;
                break;
            case R.id.sampling_rate_48:
                mSeniorConfig.mAudioBitrate = 48;
                break;
            default:
                mSeniorConfig.mAudioBitrate = 48;
                break;
        }
    }

    private void switchAudioEncodePattern(int id) {
        switch (id) {
            case R.id.audio_encoder_aac_lc:
                mSeniorConfig.mAudioEncodedFunc = AVConst.PROFILE_AAC_LOW;
                break;
            case R.id.audio_encoder_he_aac:
                mSeniorConfig.mAudioEncodedFunc = AVConst.PROFILE_AAC_HE;
                break;
            case R.id.audio_encoder_he_aac_v2:
                mSeniorConfig.mAudioEncodedFunc = AVConst.PROFILE_AAC_HE_V2;
                break;
            default:
                mSeniorConfig.mAudioEncodedFunc = AVConst.PROFILE_AAC_LOW;
                break;
        }
    }

    private void switchVoiceChannel(int id) {
        switch (id) {
            case R.id.voice_channel_single:
                mSeniorConfig.mVoiceChannel = BaseConstants.DEFAULT_AUDIO_CHANNELS;
                break;
            case R.id.voice_channel_double:
                mSeniorConfig.mVoiceChannel = 2;
                break;
            default:
                mSeniorConfig.mVoiceChannel = BaseConstants.DEFAULT_AUDIO_CHANNELS;
                break;
        }
    }

    private void switchDevicePattern(int id) {
        switch (id) {
            case R.id.device_pattern_vertical:
                mSeniorConfig.mOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT;
                break;
            case R.id.device_pattern_horizontal:
                mSeniorConfig.mOrientation = ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE;
                break;
            case R.id.device_pattern_dynamic:
                mSeniorConfig.mOrientation = ActivityInfo.SCREEN_ORIENTATION_FULL_SENSOR;
                break;
            default:
                mSeniorConfig.mOrientation = ActivityInfo.SCREEN_ORIENTATION_PORTRAIT;
                break;
        }
    }

    private void switchCameraPattern(int id) {
        switch (id) {
            case R.id.foreground_camera:
                mSeniorConfig.mCameraPattern = CameraCapture.FACING_FRONT;
                break;
            case R.id.back_camera:
                mSeniorConfig.mCameraPattern = CameraCapture.FACING_BACK;
                break;
            case R.id.usb_camera:
                mSeniorConfig.mCameraPattern = CameraCapture.FACING_FRONT;
                break;
            default:
                mSeniorConfig.mCameraPattern = CameraCapture.FACING_FRONT;
                break;
        }
    }

    private void switchAudioBitRate(int id) {

        switch (id) {
            case R.id.audio_bit_rate_32:
                mSeniorConfig.mAudioBitrate = 32;
                break;
            case R.id.audio_bit_rate_48:
                mSeniorConfig.mAudioBitrate = 48;
                break;
            case R.id.audio_bit_rate_64:
                mSeniorConfig.mAudioBitrate = 64;
                break;
            default:
                mSeniorConfig.mAudioBitrate = 48;
                break;
        }
    }

    @Override
    public void onToggle(boolean on, int id) {
        switch (id) {
            case R.id.tb_background_push:
                mSeniorConfig.mBackgroundPush = on;
                break;
            case R.id.tb_live_pip:
                mSeniorConfig.mPIPMode = on;
                break;
            default:
                break;

        }
    }
}
