package com.jdcloud.media.demo.push.ui;


import android.Manifest;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.drawable.Drawable;
import android.hardware.SensorManager;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.text.TextUtils;
import android.view.MotionEvent;
import android.view.OrientationEventListener;
import android.view.Surface;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.RadioGroup;
import android.widget.RelativeLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.jdcloud.media.demo.MainActivity;
import com.jdcloud.media.demo.R;
import com.jdcloud.media.demo.common.Constant;
import com.jdcloud.media.demo.common.QRCodeScannerActivity;
import com.jdcloud.media.demo.common.view.CustomDialog;
import com.jdcloud.media.demo.push.PushUtil;
import com.jdcloud.media.demo.push.config.BaseConfig;
import com.jdcloud.media.demo.utils.ActivityUtil;
import com.jdcloud.media.demo.utils.CommonUtils;
import com.jdcloud.media.demo.utils.LogUtil;
import com.jdcloud.media.demo.utils.PermissionUtils;
import com.jdcloud.media.demo.utils.SharePreferenceUtil;
import com.jdcloud.media.demo.utils.ToastUtil;
import com.jdcloud.media.live.base.AVConst;
import com.jdcloud.media.live.capture.screen.JDCloudScreenLive;
import com.jdcloud.media.live.coder.encoder.VideoEncodeFormat;
import com.jdcloud.media.live.config.BaseConstants;
import com.jdcloud.media.live.listener.ErrorListener;
import com.jdcloud.media.live.listener.InfoListener;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;

public class PushSettingActivity extends PushBaseActivity {

    private final static String TAG = PushSettingActivity.class.getSimpleName();
    @BindView(R.id.live_push)
    Button mPushBtn;
    @BindView(R.id.action_bar_back)
    RelativeLayout mActionBarBack;
    @BindView(R.id.action_bar_setting)
    RelativeLayout mActionBarSetting;
    @BindView(R.id.action_bar_title)
    TextView mTitle;
    @BindView(R.id.et_live_url)
    EditText mEditText;
    @BindView(R.id.live_resolution_pattern)
    RadioGroup mResolution;
    @BindView(R.id.live_performance_pattern)
    RadioGroup mPerformance;
    @BindView(R.id.live_capture_pattern)
    RadioGroup mCaptureFrom;
    @BindView(R.id.rl_live_encoder)
    RelativeLayout mRLEncoder;
    @BindView(R.id.rl_live_performance)
    RelativeLayout mRLPerformance;
    @BindView(R.id.rl_live_sense)
    RelativeLayout mRLSense;
    @BindView(R.id.live_screen_push_operation)
    TextView mTVScreenOperationTip;

    private JDCloudScreenLive mStreamer;
    private BaseConfig mBaseConfig;
    private OrientationEventListener mOrientationEventListener;
    private boolean mIsLandscape;
    private int mLastRotation;
    private boolean isScreen;
    private boolean isScreenStarted;
    private boolean mHWEncoderUnsupported;
    private boolean mSWEncoderUnsupported;
    private CustomDialog mBackDialog;
    private String mLogoPath = "assets://jdc_logo.jpg";
    private Handler mHandler;
    private static final int MSG_SHOW_TOAST = 0x1001;
    private static final int MSG_RE_START = 0x1002;
    private static final int MSG_UPDATE_UI = 0x1003;
    private static final int DELAY_TIME = 3000;

    @Override
    public void initView() {
        setContentView(R.layout.activity_live_setting);
        ButterKnife.bind(this);
        ActivityUtil.INSTANCE.addActivity(this);
    }

    @Override
    public void initData() {
        super.initData();
        mBaseConfig = (BaseConfig) SharePreferenceUtil.getInstance().getBean(SharePreferenceUtil.BASE_CONFIG);
        if (mBaseConfig == null) {
            mBaseConfig = new BaseConfig();
        }
        mEditText.setText(SharePreferenceUtil.getInstance().getPushUrl());
        mBaseConfig.mUrl = mEditText.getText().toString();
        mBaseConfig.mEncodeMethod = AVConst.CODEC_ID_HEVC;//目前只支持h264
        mHandler = new UIHandler();
        //分辨率
        if (mBaseConfig.mResolution != -1) {
            mResolution.check(getResolutionId(mBaseConfig.mResolution));
        } else {
            switchResolution(mResolution.getCheckedRadioButtonId());
        }
        //性能模式
        if (mBaseConfig.mPerformance != -1) {
            mPerformance.check(getPerformanceId(mBaseConfig.mPerformance));
        } else {
            switchPerformance(mPerformance.getCheckedRadioButtonId());
        }
        //采集来源
        if (mBaseConfig.mCaptureFrom != null) {
            mCaptureFrom.check(getCaptureId(mBaseConfig.mCaptureFrom));
        } else {
            switchCaptureFrom(mCaptureFrom.getCheckedRadioButtonId());
        }

    }

    private int getResolutionId(int res) {
        int id = R.id.live_resolution_360;
        switch (res) {
            case BaseConstants.VIDEO_RESOLUTION_360P:
                id = R.id.live_resolution_360;
                break;
            case BaseConstants.VIDEO_RESOLUTION_540P:
                id = R.id.live_resolution_540;
                break;
            case BaseConstants.VIDEO_RESOLUTION_720P:
                id = R.id.live_resolution_720;
                break;
            default:
                break;
        }
        return id;
    }

    private int getPerformanceId(int per) {
        int id = R.id.live_performance_low;
        switch (per) {
            case VideoEncodeFormat.ENCODE_PROFILE_LOW_POWER:
                id = R.id.live_performance_low;
                break;
            case VideoEncodeFormat.ENCODE_PROFILE_BALANCE:
                id = R.id.live_performance_balance;
                break;
            case VideoEncodeFormat.ENCODE_PROFILE_HIGH_PERFORMANCE:
                id = R.id.live_performance_height;
                break;
            default:
                break;
        }
        return id;
    }

    private int getCaptureId(String cap) {
        int id = R.id.live_capture_camera;
        switch (cap) {
            case Constant.PUSH_FROM_CAMERA:
                id = R.id.live_capture_camera;
                break;
            case Constant.PUSH_FROM_SCREEN:
                id = R.id.live_capture_screen;
                break;
            default:
                break;
        }
        return id;

    }

    private void hideForScreen() {
        isScreen = true;
        mRLEncoder.setVisibility(View.GONE);
        mRLPerformance.setVisibility(View.GONE);
        mRLSense.setVisibility(View.GONE);
//        mTVScreenOperationTip.setVisibility(View.VISIBLE);
        mTVScreenOperationTip.getPaint().setFlags(Paint.UNDERLINE_TEXT_FLAG);
        initScreen();
    }

    private void initScreen() {
        if (mStreamer == null) {
            mStreamer = new JDCloudScreenLive(this);

            mStreamer.setUrl(mBaseConfig.mUrl);
            mStreamer.setTargetFps(Constant.DEFAULT_FRAME_RATE);
            mStreamer.setTargetResolution(mBaseConfig.mResolution);
            mStreamer.setEncodeMethod(BaseConstants.ENCODE_METHOD_HARDWARE);
            mStreamer.setVideoCodecId(AVConst.CODEC_ID_AVC);
            mStreamer.setLandscape(mIsLandscape);
            mStreamer.setOnInfoListener(mOnInfoListener);
            mStreamer.setOnErrorListener(mOnErrorListener);
            mLastRotation = getDisplayRotation();
            mStreamer.setAudioChannels(1);

        }
    }

    private InfoListener mOnInfoListener =
            new InfoListener() {
                @Override
                public void onInfo(int what, int msg1, int msg2) {
                    switch (what) {
                        case BaseConstants.LIVE_OPEN_SUCCESS:
                            isScreenStarted = true;
                            mHandler.sendEmptyMessage(MSG_UPDATE_UI);
                            break;
                        case BaseConstants.LIVE_FRAME_SEND_SLOW:
                            LogUtil.d(TAG, "STREAMER_FRAME_SEND_SLOW " + msg1 + "ms");
                            mHandler.obtainMessage(MSG_SHOW_TOAST, "网络状况异常").sendToTarget();
                            break;
                        case BaseConstants.LIVE_EST_BW_RAISE:
                            LogUtil.d(TAG, "BW raise to " + msg1 / 1000 + "kbps");
                            break;
                        case BaseConstants.LIVE_EST_BW_DROP:
                            LogUtil.d(TAG, "BW drop to " + msg1 / 1000 + "kpbs");
                            break;
                        default:
                            LogUtil.d(TAG, "OnInfo: " + what + " msg1: " + msg1 + " msg2: " + msg2);
                            break;
                    }
                }
            };

    private ErrorListener mOnErrorListener =
            new ErrorListener() {
                @Override
                public void onError(int what, int msg1, int msg2) {
                    switch (what) {
                        case BaseConstants.STREAMER_ERROR_DNS_PARSE_FAILED:
                            LogUtil.d(TAG, "STREAMER_ERROR_DNS_PARSE_FAILED");
                            break;
                        case BaseConstants.STREAMER_ERROR_CONNECT_FAILED:
                            LogUtil.d(TAG, "STREAMER_ERROR_CONNECT_FAILED");
                            break;
                        case BaseConstants.STREAMER_ERROR_PUBLISH_FAILED:
                            LogUtil.d(TAG, "STREAMER_ERROR_PUBLISH_FAILED");
                            break;
                        case BaseConstants.STREAMER_ERROR_CONNECT_BREAKED:
                            LogUtil.d(TAG, "STREAMER_ERROR_CONNECT_BREAK");
                            break;
                        case BaseConstants.STREAMER_ERROR_AV_ASYNC:
                            LogUtil.d(TAG, "STREAMER_ERROR_AV_ASYNC " + msg1 + "ms");
                            break;
                        case BaseConstants.VIDEO_ENCODER_ERROR_UNSUPPORTED:
                            LogUtil.d(TAG, "STREAMER_VIDEO_ENCODER_ERROR_UNSUPPORTED");
                            break;
                        case BaseConstants.VIDEO_ENCODER_ERROR_UNKNOWN:
                            LogUtil.d(TAG, "STREAMER_VIDEO_ENCODER_ERROR_UNKNOWN");
                            break;
                        case BaseConstants.AUDIO_ENCODER_ERROR_UNSUPPORTED:
                            LogUtil.d(TAG, "STREAMER_AUDIO_ENCODER_ERROR_UNSUPPORTED");
                            break;
                        case BaseConstants.AUDIO_ENCODER_ERROR_UNKNOWN:
                            LogUtil.d(TAG, "STREAMER_AUDIO_ENCODER_ERROR_UNKNOWN");
                            break;
                        case BaseConstants.AUDIO_RECORDER_ERROR_START_FAILED:
                            LogUtil.d(TAG, "STREAMER_AUDIO_RECORDER_ERROR_START_FAILED");
                            break;
                        case BaseConstants.AUDIO_RECORDER_ERROR_UNKNOWN:
                            LogUtil.d(TAG, "STREAMER_AUDIO_RECORDER_ERROR_UNKNOWN");
                            break;
                        case BaseConstants.SCREEN_RECORD_UNSUPPORTED:
                            LogUtil.d(TAG, "STREAMER_SCREEN_RECORD_UNSUPPORTED");
                            mHandler.obtainMessage(MSG_SHOW_TOAST, "手机系统版本低于21无法使用录屏").sendToTarget();
                            break;
                        case BaseConstants.SCREEN_RECORD_PERMISSION_DENIED:
                            LogUtil.d(TAG, "STREAMER_SCREEN_RECORD_PERMISSION_DENIED");
                            stopStream();
                            mHandler.obtainMessage(MSG_SHOW_TOAST, "没有开启录屏权限，请开启").sendToTarget();
                            break;
                        case BaseConstants.STREAMER_ERROR_ALREADY_EXIST_STREAM_NAME:
                            LogUtil.d(TAG, "流名相同 请更换");
                            break;
                        case BaseConstants.STREAMER_ERROR_SIGNATURE_NOT_MATCH:
                            LogUtil.d(TAG, "签名不匹配");
                            break;
                        case  BaseConstants.STREAMER_ERROR_REFER_NOT_MATCH:
                            LogUtil.d(TAG, "refer鉴权失败");
                            break;
                        case BaseConstants.STREAMER_ERROR_FORBIDDEN:
                            LogUtil.d(TAG, "流被拒绝");
                            break;
                        case BaseConstants.STREAMER_ERROR_INVALID_ACCESS_KEY:
                            LogUtil.d(TAG, "无效的AccessKey");
                            break;
                        case  BaseConstants.STREAMER_ERROR_MISS_ACCESS_KEY:
                            LogUtil.d(TAG, "缺少access key");
                            break;
                        case BaseConstants.STREAMER_ERROR_INTERNAL_ERROR:
                            LogUtil.d(TAG, "推流失败 未知原因");
                            break;
                        default:
                            LogUtil.d(TAG, "what=" + what + " msg1=" + msg1 + " msg2=" + msg2);
                            break;
                    }
                    switch (what) {
                        case BaseConstants.VIDEO_ENCODER_ERROR_UNSUPPORTED:
                        case BaseConstants.VIDEO_ENCODER_ERROR_UNKNOWN: {
                            handleEncodeError();
                            stopStream();
                            mHandler.sendEmptyMessageDelayed(MSG_RE_START, DELAY_TIME);
                        }
                        break;
                        default:
                            break;
                    }
                }
            };

    private void startStream() {
        //fix bug LIVE-500
        if (PushUtil.INSTANCE.isFloatViewShow()) {
            mHandler.obtainMessage(MSG_SHOW_TOAST, "请先关闭悬浮窗再进行此操作").sendToTarget();
            return;
        }
        mStreamer.startPush();
        mPushBtn.setText(R.string.end_living);
        showWaterMark();
    }

    private void stopStream() {
        AsyncTask.execute(new Runnable() {
            @Override
            public void run() {
                mStreamer.stopPush();
                isScreenStarted = false;
                mHandler.sendEmptyMessage(MSG_UPDATE_UI);
            }
        });

    }


    private void showWaterMark() {
        if (!mIsLandscape) {
//            mStreamer.showWaterMarkLogo(mLogoPath, 0, 0.079f, 0.23f, 0.06f, 1);
            mStreamer.showWaterMarkTime(16, 0.6f, 0.08f, 0.35f, Color.WHITE, 1.0f);
        } else {
//            mStreamer.showWaterMarkLogo(mLogoPath, 0.05f, 0.09f, 0, 0.20f, 0.8f);
            mStreamer.showWaterMarkTime(16, 0.01f, 0.03f, 0.22f, Color.WHITE, 1.0f);
        }
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        if (mHandler != null) {
            mHandler.removeCallbacksAndMessages(null);
            mHandler = null;
        }
        if (mOrientationEventListener != null) {
            mOrientationEventListener.disable();
        }
        if (mStreamer != null) {
            mStreamer.stopPush();
            mStreamer = null;
        }
    }

    private void hideWaterMark() {
//        mStreamer.hideWaterMarkLogo();
        mStreamer.hideWaterMarkTime();
    }

    private void handleEncodeError() {
        int encodeMethod = mStreamer.getVideoEncodeMethod();
        if (encodeMethod == BaseConstants.ENCODE_METHOD_HARDWARE) {
            mHWEncoderUnsupported = true;
            if (mSWEncoderUnsupported) {
                mStreamer.setEncodeMethod(BaseConstants.ENCODE_METHOD_SOFTWARE);
            } else {
                mStreamer.setEncodeMethod(BaseConstants.ENCODE_METHOD_SOFTWARE);
            }
        } else if (encodeMethod == BaseConstants.ENCODE_METHOD_SOFTWARE) {
            mSWEncoderUnsupported = true;
            if (mHWEncoderUnsupported) {
            } else {
                mStreamer.setEncodeMethod(BaseConstants.ENCODE_METHOD_HARDWARE);
            }
        }
    }


    private void showForNormal() {
        isScreen = false;
        mRLEncoder.setVisibility(View.VISIBLE);
        mRLPerformance.setVisibility(View.VISIBLE);
        mRLSense.setVisibility(View.VISIBLE);
        mTVScreenOperationTip.setVisibility(View.GONE);
    }


    @Override
    public void initListener() {
        mEditText.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                Drawable drawable = mEditText.getCompoundDrawables()[2];
                if (drawable == null) {
                    return false;
                }
                if (event.getAction() != MotionEvent.ACTION_UP) {
                    return false;
                }
                if (event.getX() > mEditText.getWidth() - mEditText.getPaddingRight() - drawable.getIntrinsicWidth()) {
                    if (!PermissionUtils.checkPermission(PushSettingActivity.this, Manifest.permission.CAMERA)) {
                        // 申请权限
                        PermissionUtils.requestPermissions(PushSettingActivity.this, new String[]{Manifest.permission.CAMERA}, 100);
                        return false;
                    }
                    if (!PushUtil.INSTANCE.isFloatViewShow()) {
                        Intent i = new Intent(PushSettingActivity.this, QRCodeScannerActivity.class);
                        startActivityForResult(i, Constant.SCAN_PUSH_URL_REQUEST);
                    }
                }
                return false;
            }
        });

        mCaptureFrom.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
                                                    @Override
                                                    public void onCheckedChanged(RadioGroup group, int checkedId) {
                                                        if (checkedId == R.id.live_capture_camera) {
                                                            showForNormal();
                                                        } else if (checkedId == R.id.live_capture_screen) {
                                                            hideForScreen();
                                                        }
                                                    }
                                                }
        );
        mOrientationEventListener = new OrientationEventListener(this,
                SensorManager.SENSOR_DELAY_NORMAL) {
            @Override
            public void onOrientationChanged(int orientation) {
                int rotation = getDisplayRotation();
                if (rotation != mLastRotation) {
                    mIsLandscape = (rotation % 180) != 0;
                    mStreamer.setLandscape(mIsLandscape);
                    hideWaterMark();
                    showWaterMark();
                    mLastRotation = rotation;
                }
            }
        };

        mResolution.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchResolution(i);
            }
        });
        mPerformance.setOnCheckedChangeListener(new RadioGroup.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(RadioGroup radioGroup, int i) {
                switchPerformance(i);
            }
        });
    }

    private void switchResolution(int id) {
        switch (id) {
            case R.id.live_resolution_360:
                mBaseConfig.mResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
            case R.id.live_resolution_540:
                mBaseConfig.mResolution = BaseConstants.VIDEO_RESOLUTION_540P;
                break;
            case R.id.live_resolution_720:
                mBaseConfig.mResolution = BaseConstants.VIDEO_RESOLUTION_720P;
                break;
            default:
                mBaseConfig.mResolution = BaseConstants.VIDEO_RESOLUTION_360P;
                break;
        }
        if (mStreamer != null) {
            mStreamer.setTargetResolution(mBaseConfig.mResolution);
        }
    }

    private void switchPerformance(int id) {
        switch (id) {
            case R.id.live_performance_low:
                mBaseConfig.mPerformance = VideoEncodeFormat.ENCODE_PROFILE_LOW_POWER;
                break;
            case R.id.live_performance_balance:
                mBaseConfig.mPerformance = VideoEncodeFormat.ENCODE_PROFILE_BALANCE;
                break;
            case R.id.live_performance_height:
                mBaseConfig.mPerformance = VideoEncodeFormat.ENCODE_PROFILE_HIGH_PERFORMANCE;
                break;
            default:
                mBaseConfig.mPerformance = VideoEncodeFormat.ENCODE_PROFILE_DEFAULT;
                break;
        }
    }

    private void switchCaptureFrom(int id) {
        switch (id) {
            case R.id.live_capture_camera:
                mBaseConfig.mCaptureFrom = Constant.PUSH_FROM_CAMERA;
                break;
            case R.id.live_capture_screen:
                mBaseConfig.mCaptureFrom = Constant.PUSH_FROM_SCREEN;
                break;
            default:
                mBaseConfig.mCaptureFrom = Constant.PUSH_FROM_CAMERA;
                break;
        }
    }

    private int getDisplayRotation() {
        int rotation = getWindowManager().getDefaultDisplay().getRotation();
        switch (rotation) {
            case Surface.ROTATION_0:
                return 0;
            case Surface.ROTATION_90:
                return 90;
            case Surface.ROTATION_180:
                return 180;
            case Surface.ROTATION_270:
                return 270;
        }
        return 0;
    }

    @Override
    public void setActionBar() {
        mTitle.setText(R.string.title_push);
        mActionBarBack.setVisibility(View.VISIBLE);
        mActionBarSetting.setVisibility(View.VISIBLE);
    }

    //高级设置
    @OnClick(R.id.action_bar_setting)
    public void startSeniorSetting() {
        startNext(PushSeniorSettingActivity.class);
    }

    //返回
    @OnClick(R.id.action_bar_back)
    public void goBack() {
        if (isScreenStarted) {
            if (mBackDialog != null && !mBackDialog.isShowing()) {
                mBackDialog.show();
            } else {
                mBackDialog = new CustomDialog.Builder(this).setTitle(R.string.dialog_exit_title).setContent(R.string.dialog_exit_content)
                        .setOkBtn(R.string.dialog_exit_ok).setCancelBtn(R.string.dialog_exit_cancel).setOkListener(
                                new View.OnClickListener() {
                                    @Override
                                    public void onClick(View v) {
                                        stopStream();
                                        mBackDialog.dismiss();
                                        onBackPressed();
                                    }
                                }
                        ).setCancelListener(new View.OnClickListener() {
                            @Override
                            public void onClick(View v) {
                                mBackDialog.dismiss();
                            }
                        }).createDialog();
                mBackDialog.show();
            }
        } else {
            onBackPressed();
        }
    }

    //直播
    @OnClick(R.id.live_push)
    public void goLivePush() {
        if (checkUrl()) {
            SharePreferenceUtil.getInstance().setPushUrl(mEditText.getText().toString());
            if (isScreen) {
                if (isScreenStarted) {
                    stopStream();
                } else {
                    if (!CommonUtils.isNetworkOk(this)) {
                        Toast.makeText(this, "请检查网络连接！", Toast.LENGTH_SHORT).show();
                    } else {
                        startStream();
                    }
                }

            } else {
                if (PushUtil.INSTANCE.isPushIng()) {
                    Toast.makeText(this, "请先关闭悬浮窗！", Toast.LENGTH_SHORT).show();
                } else {
                    ActivityUtil.INSTANCE.finishActivity(PushActivity.class);
                    startNext(PushActivity.class);
                }
            }
        }
    }

    private void startNext(Class<?> clazz) {
        Intent i = new Intent(this, clazz);
        i.putExtra(Constant.PUSH_BASE_CONFIG, mBaseConfig);
        SharePreferenceUtil.getInstance().putBean(SharePreferenceUtil.BASE_CONFIG, mBaseConfig);
        startActivity(i);
    }

    @Override
    public void onBackPressed() {
        if (isScreenStarted) {
            goBack();
        } else {
            super.onBackPressed();
            startComponent(MainActivity.class);
            finish();
        }
    }

    private boolean checkUrl() {
        boolean result = true;
        if (TextUtils.isEmpty(mEditText.getText())) {
            mHandler.obtainMessage(MSG_SHOW_TOAST, "请填写正确的推流地址").sendToTarget();
            return false;
        }
        if (!CommonUtils.checkPushUrl(mEditText.getText().toString())) {
            mHandler.obtainMessage(MSG_SHOW_TOAST, "请填写正确的推流地址").sendToTarget();
            return false;
        }
        mBaseConfig.mUrl = mEditText.getText().toString();
        LogUtil.d("pushUrl",mEditText.getText().toString());
        return result;
    }

    private void updateUiForScreenStatus() {
        if (isScreenStarted) {
            mEditText.setClickable(false);
            mEditText.setEnabled(false);
            disableRadioGroup(mResolution);
            disableRadioGroup(mCaptureFrom);
        } else {
            mEditText.setClickable(true);
            mEditText.setEnabled(true);
            enableRadioGroup(mResolution);
            enableRadioGroup(mCaptureFrom);
            mPushBtn.setText(R.string.start_living);
            hideWaterMark();
        }
    }

    private void disableRadioGroup(RadioGroup rg) {
        for (int i = 0; i < rg.getChildCount(); i++) {
            rg.getChildAt(i).setEnabled(false);
        }
    }

    private void enableRadioGroup(RadioGroup rg) {
        for (int i = 0; i < rg.getChildCount(); i++) {
            rg.getChildAt(i).setEnabled(true);
        }
    }

    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        //扫描结果回调
        if (requestCode == Constant.SCAN_PUSH_URL_REQUEST && resultCode == RESULT_OK) {
            Bundle bundle = data.getExtras();
            String scanResult = bundle.getString(QRCodeScannerActivity.SCAN_RESULT);
            //将扫描出的信息显示出来
            mEditText.setText(scanResult);
            mBaseConfig.mUrl = scanResult;
            SharePreferenceUtil.getInstance().setPushUrl(scanResult);
        }
    }

    class UIHandler extends Handler {
        @Override
        public void handleMessage(Message msg) {

            switch (msg.what) {
                case MSG_RE_START:
                    startStream();
                    break;
                case MSG_SHOW_TOAST:
                    String content = (String) msg.obj;
                    ToastUtil.makeText(PushSettingActivity.this, content, Toast.LENGTH_SHORT);
                    break;
                case MSG_UPDATE_UI:
                    updateUiForScreenStatus();
                    break;
                default:
                    break;
            }
        }
    }
}
