package com.jdcloud.media.demo.utils;

import android.content.Context;
import android.content.SharedPreferences;
import android.util.Base64;

import com.jdcloud.media.demo.DemoApplication;
import com.jdcloud.media.demo.R;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;
import java.text.SimpleDateFormat;
import java.util.Date;

public class SharePreferenceUtil {
    private static SharePreferenceUtil preferenceUtils;
    private String PUSH_URL = "push_url";
    private SharedPreferences sp;
    private Context mContext;
    public static final String BASE_CONFIG = "base_config";

    private SharePreferenceUtil(Context context) {
        mContext = context;
        sp = context.getSharedPreferences(PUSH_URL, Context.MODE_PRIVATE);
    }

    public synchronized static SharePreferenceUtil getInstance() {
        if (null == preferenceUtils) {
            preferenceUtils = new SharePreferenceUtil(DemoApplication.getContext());
        }
        return preferenceUtils;
    }

    public void setPushUrl(String url) {
        sp.edit().putString(PUSH_URL, url).commit();
    }

    public String getPushUrl() {
        String url = mContext.getResources().getString(R.string.push_url);
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("MMddHHmmss");
        Date date = new Date();
        String timeData = simpleDateFormat.format(date);

        return sp.getString(PUSH_URL, url + timeData);
    }


    public void putBean(String key, Object obj) {
        if (obj instanceof Serializable) {// obj必须实现Serializable接口，否则会出问题
            try {
                ByteArrayOutputStream baos = new ByteArrayOutputStream();
                ObjectOutputStream oos = new ObjectOutputStream(baos);
                oos.writeObject(obj);
                String string64 = new String(Base64.encode(baos.toByteArray(), 0));
                SharedPreferences.Editor editor = sp.edit();
                editor.putString(key, string64).commit();
            } catch (IOException e) {
                e.printStackTrace();
            }

        } else {
            throw new IllegalArgumentException("the obj must implement Serializble");
        }

    }

    public Object getBean(String key) {
        Object obj = null;
        try {
            String base64 = sp.getString(key, "");
            if (base64.equals("")) {
                return null;
            }
            byte[] base64Bytes = Base64.decode(base64.getBytes(), 1);
            ByteArrayInputStream bais = new ByteArrayInputStream(base64Bytes);
            ObjectInputStream ois = new ObjectInputStream(bais);
            obj = ois.readObject();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return obj;
    }
}
