package com.jdcloud.media.demo.utils;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Color;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.bumptech.glide.Glide;
import com.jdcloud.media.demo.R;

import java.io.File;

public class ToastUtil {

    private static final String TAG = ToastUtil.class.getSimpleName();

    private static volatile ToastUtil instance = null;
    public static int LENGTH_LONG = Toast.LENGTH_LONG;
    private ImageView mImage;
    private Toast mToast;

    private ToastUtil() {
        LogUtil.d(TAG, "show image toast");
    }

    public static ToastUtil getToast() {
        if (instance == null) {
            synchronized (ToastUtil.class) {
                if (instance == null) {
                    instance = new ToastUtil();
                }
            }
        }
        return instance;
    }

    public void makeToast(Context context, ViewGroup root, int duration) {
        if (duration <= 0) {
            duration = LENGTH_LONG;
        }
        mToast = new Toast(context);
        View toastView = LayoutInflater.from(context).inflate(R.layout.layout_toast_image, root);
        mToast.setGravity(Gravity.CENTER, 0, 0);
        mImage = toastView.findViewById(R.id.iv_toast_content);
        mToast.setDuration(duration);
        mToast.setView(toastView);
    }

    public void makeFullToast(Context context, ViewGroup root, int duration) {
        if (duration <= 0) {
            duration = LENGTH_LONG;
        }
        mToast = new Toast(context);
        View toastView = LayoutInflater.from(context).inflate(R.layout.layout_cut_screen, root);
        mToast.setGravity(Gravity.CENTER, 0, 0);
        mImage = toastView.findViewById(R.id.iv_cut_screen_sub);
        mToast.setDuration(duration);
        mToast.setView(toastView);
    }

    public void setImagePath(String path) {
        if (mToast == null) {
            return;
        }
        Glide.with(mImage.getContext()).asBitmap().load(new File(path)).into(mImage);
    }

    public void setImageBitmap(Bitmap bitmap) {
        if (mToast == null) {
            return;
        }
        Glide.with(mImage.getContext()).asBitmap().load(bitmap).into(mImage);
    }

    public void showToast() {
        if (mToast == null) {
            return;
        }
        mToast.show();
    }

    public static void makeText(Context context, String showText, int showTime) {
        Toast toast = Toast.makeText(context,showText, showTime);
        View view = toast.getView();
        TextView tv=view.findViewById(android.R.id.message);
        tv.setTextColor(Color.WHITE);
        tv.setBackgroundColor(Color.TRANSPARENT);
        tv.setPadding(15,5,15,5);
//        tv.setBackgroundColor(context.getResources().getColor(android.R.color.darker_gray));
        view.setBackgroundResource(R.drawable.common_round_rect_black);
//        toast.setView(view);
        toast.show();
    }
    public static void makeText(Context context, int showText, int showTime) {
        Toast toast = Toast.makeText(context,showText, showTime);
        View view = toast.getView();
        TextView tv=view.findViewById(android.R.id.message);
        tv.setTextColor(Color.WHITE);
        tv.setBackgroundColor(Color.TRANSPARENT);
        tv.setPadding(15,5,15,5);
        view.setBackgroundResource(R.drawable.common_round_rect_black);
//        toast.setView(view);
        toast.show();
    }
}
